# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2025-01-04 21:48
# @Author : 毛鹏

import json as json_lib
from urllib.parse import urlencode

from PySide6.QtCore import QUrl, QObject, Signal, Slot, QByteArray
from PySide6.QtNetwork import QNetworkAccessManager, QNetworkRequest, QNetworkReply


class HttpRequest(QObject):
    request_finished = Signal(str)

    def __init__(self):
        super().__init__()
        self.manager = QNetworkAccessManager(self)
        self.manager.finished.connect(self.on_finished)

    def _prepare_request(self, url, headers=None, params=None):
        if params:
            url += "?" + urlencode(params)
        request = QNetworkRequest(QUrl(url))
        if headers:
            for key, value in headers.items():
                request.setRawHeader(key.encode('utf-8'), value.encode('utf-8'))
        return request

    def _prepare_body(self, data=None, json=None):
        if json:
            body = QByteArray(json_lib.dumps(json).encode('utf-8'))
            content_type = "application/json"
        elif data:
            body = QByteArray(urlencode(data).encode('utf-8'))
            content_type = "application/x-www-form-urlencoded"
        else:
            body = QByteArray()
            content_type = None

        return body, content_type

    def get(self, url, headers=None, params=None):
        request = self._prepare_request(url, headers, params)
        self.manager.get(request)

    def post(self, url, headers=None, params=None, data=None, json=None):
        request = self._prepare_request(url, headers, params)
        body, content_type = self._prepare_body(data, json)
        if content_type:
            request.setHeader(QNetworkRequest.ContentTypeHeader, content_type)  # type: ignore
        self.manager.post(request, body)

    def put(self, url, headers=None, params=None, data=None, json=None):
        request = self._prepare_request(url, headers, params)
        body, content_type = self._prepare_body(data, json)
        if content_type:
            request.setHeader(QNetworkRequest.ContentTypeHeader, content_type)  # type: ignore
        self.manager.put(request, body)

    def delete(self, url, headers=None, params=None):
        request = self._prepare_request(url, headers, params)
        self.manager.deleteResource(request)

    @Slot(QNetworkReply)
    def on_finished(self, reply):
        if reply.error() == QNetworkReply.NoError:  # type: ignore
            data = reply.readAll().data().decode('utf-8')
            self.request_finished.emit(data)
        else:
            self.request_finished.emit(f"Error: {reply.errorString()}")
        reply.deleteLater()



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 2024-08-16 17:05
# @Author : 毛鹏

from PySide6.QtCore import *
from PySide6.QtGui import *
from PySide6.QtWidgets import *

from mangoui.settings.settings import THEME


class MangoCredits(QWidget):
    update_label = Signal(str)

    def __init__(self, copyright, version, ):
        super().__init__()
        self.copyright = copyright
        self.version = version

        self.widget_layout = QHBoxLayout(self)
        self.widget_layout.setContentsMargins(0, 0, 0, 0)

        style = f"""
        #bg_frame {{
            border-radius: {THEME.border_radius};
            background-color: {THEME.primary_100};
            border: 1px solid {THEME.bg_300};
            padding: 6px 16px; /* 调整内边距使字体垂直居中 */
        }}
        
        QLabel {{
            font-family: {THEME.font.family};
            font-size: {THEME.font.text_size}px;
            color: {THEME.text_100};
            padding: 0 8px;
            background: transparent; /* 确保标签背景透明 */
            /* 移除最小高度设置，让标签根据内容自适应高度 */
            /* line-height: 20px; 移除固定行高 */
        }}
        
        QLabel:first-child {{
            font-weight: 500;
        }}
        
        QLabel:last-child {{
            color: {THEME.text_200};
        }}
        """

        self.bg_frame = QFrame()
        self.bg_frame.setObjectName("bg_frame")
        self.bg_frame.setStyleSheet(style)
        # 移除最小高度设置，让组件根据内容自适应高度
        self.bg_frame.setFrameShape(QFrame.NoFrame)  # 确保框架没有边框
        self.bg_frame.setLineWidth(0)  # 确保框架线宽为0

        self.widget_layout.addWidget(self.bg_frame)

        self.bg_layout = QHBoxLayout(self.bg_frame)
        self.bg_layout.setContentsMargins(0, 0, 0, 0)
        self.bg_layout.setSpacing(10)  # 设置控件间距为10像素

        # 创建一个包含版权和版本信息的水平布局
        info_layout = QHBoxLayout()
        info_layout.setSpacing(10)  # 设置标签之间的间距
        info_layout.setContentsMargins(0, 0, 0, 0)
        info_layout.setAlignment(Qt.AlignVCenter | Qt.AlignRight)  # 设置布局内容右对齐并垂直居中
        
        self.copyright_label = QLabel()
        self.copyright_label.setText(self.copyright)
        self.copyright_label.setAlignment(Qt.AlignVCenter | Qt.AlignRight)  # type: ignore
        self.copyright_label.setObjectName("copyright_label")  # 添加对象名称便于调试
        
        # 确保文本正确设置
        self.copyright_label.setTextFormat(Qt.TextFormat.PlainText)  # type: ignore

        self.version_label = QLabel()
        self.version_label.setText(f'Version：{self.version}')
        self.version_label.setAlignment(Qt.AlignVCenter | Qt.AlignRight)  # type: ignore
        self.version_label.setObjectName("version_label")  # 添加对象名称便于调试
        
        # 确保文本正确设置
        self.version_label.setTextFormat(Qt.TextFormat.PlainText)  # type: ignore

        # 将标签添加到信息布局中
        info_layout.addWidget(self.copyright_label)
        info_layout.addWidget(self.version_label)
        
        # 将信息布局添加到主布局中，并右对齐
        self.bg_layout.addSpacerItem(QSpacerItem(20, 20, QSizePolicy.Expanding, QSizePolicy.Minimum))  # type: ignore
        self.bg_layout.addLayout(info_layout)
        
        # 确保标签可见并正确调整大小
        self.copyright_label.setVisible(True)
        self.copyright_label.setWordWrap(False)  # 确保文本不换行
        self.version_label.setVisible(True)
        self.version_label.setWordWrap(False)  # 确保文本不换行
        
        # 调整标签大小以适应内容
        self.copyright_label.adjustSize()
        self.version_label.adjustSize()
        
        self.update_label.connect(self.set_text)

    def set_text(self, _str):
        self.copyright_label.setText(_str)
        # 确保文本设置后标签能正确显示
        self.copyright_label.adjustSize()



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-09-19 17:54
# @Author : 毛鹏
from typing import Optional

from mangoui import *

from src.pages.parent.parent import Parent
from src.tools.components.message import response_message
from src.tools.methods import Methods


class SubPage(Parent):
    def __init__(self, parent, **kwargs):
        super().__init__()
        self.parent = parent
        self.page = 1
        self.page_size = 20

        self.data: dict = {}
        self.id_key: Optional[str | None] = None
        self.superior_page: Optional[str | None] = None
        self.kwargs = kwargs

        self.form_data = [FormDataModel(**i) for i in kwargs.get('form_data', [])]

        self.layout = MangoVBoxLayout()
        self.setLayout(self.layout)

        if kwargs.get('right_data'):
            self.right_data = [RightDataModel(**i) for i in kwargs.get('right_data')]
            self.right_but = RightButton(self.right_data)
            self.right_but.clicked.connect(self.callback)
            self.layout.addWidget(self.right_but)
        self.field_list = [FieldListModel(**i) for i in kwargs.get('field_list', [])]
        if self.field_list:
            self.title_info = TitleInfoWidget()
            self.layout.addWidget(self.title_info)
        if kwargs.get('table_column'):
            self.table_column = [TableColumnModel(**i) for i in kwargs.get('table_column')]
            self.table_menu = [TableMenuItemModel(**i) for i in kwargs.get('table_menu')]
            self.table_widget = TableList(self.table_column, self.table_menu, )
            self.table_widget.pagination.click.connect(self.pagination_clicked)
            self.table_widget.clicked.connect(self.callback)
            self.layout.addWidget(self.table_widget)

    def show_data(self):
        if self.field_list:
            self.title_info.init(self.data, self.field_list)
        response_model = self.get(  # type: ignore
            self.page,
            self.page_size,
            {f'{self.id_key}_id': self.data.get('id')}
        )
        self.table_widget.set_data(response_model.data, response_model.totalSize)
        if response_model.code != 200:
            response_message(self, response_model)
        return response_model

    def sub_options(self, data: DialogCallbackModel, is_refresh=True):
        if data.subordinate == 'module':
            init_data = Methods.get_product_module(self, data)
            if is_refresh:
                data.subordinate_input_object.set_select(init_data, True)
            else:
                return init_data

    def callback(self, data):
        action = data.get('action')
        if action and hasattr(self, action):
            if data.get('row'):
                getattr(self, action)(data.get('row'))
            else:
                getattr(self, action)()

    def pagination_clicked(self, data):
        if data['action'] == 'prev':
            self.page = data['page']
        elif data['action'] == 'next':
            self.page = data['page']
        elif data['action'] == 'per_page':
            self.page_size = data['page']
        self.show_data()

    def move_up(self, row):
        row1 = self.table_widget.table_widget.currentRow()
        if row1 > 0:
            self.table_widget.table_widget.data[row1], self.table_widget.table_widget.data[row1 - 1] = \
                self.table_widget.table_widget.data[row1 - 1], self.table_widget.table_widget.data[row1]
            self.table_widget.table_widget.set_value(self.table_widget.table_widget.data)
            self.update_data(self.table_widget.table_widget.data)
            self.table_widget.table_widget.setCurrentCell(row1 - 1, 0)

    def move_down(self, row):
        row1 = self.table_widget.table_widget.currentRow()

        if row1 < len(self.table_widget.table_widget.data) - 1:
            self.table_widget.table_widget.data[row1], self.table_widget.table_widget.data[row1 + 1] = \
                self.table_widget.table_widget.data[row1 + 1], self.table_widget.table_widget.data[row1]
            self.table_widget.table_widget.set_value(self.table_widget.table_widget.data)
            self.update_data(self.table_widget.table_widget.data)
            self.table_widget.table_widget.setCurrentCell(row1 + 1, 0)

    def update_data(self, data: dict):
        pass

    def back(self):
        self.parent.set_page(self.superior_page)  # type: ignore



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-09-18 15:07
# @Author : 毛鹏
from mangoui import *

from src.pages.parent.parent import Parent
from src.tools.components.message import response_message
from src.tools.methods import Methods


class RequestThread(QThread):
    response_signal = Signal(object)

    def __init__(self, parent, page, page_size, params):
        super().__init__(parent)
        self.parent = parent
        self.page = page
        self.page_size = page_size
        self.params = params

    def run(self):
        response_model = self.parent.get(self.page, self.page_size, self.params)
        self.response_signal.emit(response_model)


class TableParent(Parent):
    def __init__(self, parent, **kwargs):
        super().__init__()
        self.parent = parent
        self.page = 1
        self.page_size = 20

        self.params = {}
        self.subpage_value = None
        self.kwargs = kwargs

        self.form_data = [FormDataModel(**i) for i in kwargs.get('form_data', [])]

        self.layout = MangoVBoxLayout(self)
        self.setLayout(self.layout)

        if kwargs.get('search_data'):
            if not isinstance(kwargs.get('search_data')[0], SearchDataModel):
                self.search_data = [SearchDataModel(**i) for i in kwargs.get('search_data', [])]
            self.titleWidget = SearchWidget(self.search_data)
            self.titleWidget.clicked.connect(self.search)
            self.layout.addWidget(self.titleWidget)
        if kwargs.get('right_data'):
            self.right_data = [RightDataModel(**i) for i in kwargs.get('right_data', [])]
            self.right_but = RightButton(self.right_data)
            self.right_but.clicked.connect(self.callback)
            self.layout.addWidget(self.right_but)
        if kwargs.get('table_column'):
            self.table_column = [TableColumnModel(**i) for i in kwargs.get('table_column', [])]
            self.table_menu = [TableMenuItemModel(**i) for i in kwargs.get('table_menu', [])]
            self.table_widget = TableList(self.table_column, self.table_menu, )
            self.table_widget.pagination.click.connect(self.pagination_clicked)
            self.table_widget.clicked.connect(self.callback)
            self.layout.addWidget(self.table_widget)

    def show_data(self):
        thread = RequestThread(self, self.page, self.page_size, self.params)
        thread.response_signal.connect(
            lambda response_model: self.table_widget.set_data(response_model.data, response_model.totalSize))
        thread.start()

    def subpage(self, row):
        self.parent.set_page(self.subpage_value, row)  # type: ignore

    def copy(self, row):
        response_message(self, self.post_copy(row.get('id')))  # type: ignore
        self.show_data()

    def callback(self, data):
        action = data.get('action')
        if action and hasattr(self, action):
            if data.get('row'):
                getattr(self, action)(row=data.get('row'))
            else:
                getattr(self, action)()

    def sub_options(self, data: DialogCallbackModel, is_refresh=True):
        if data.subordinate == 'module':
            init_data = Methods.get_product_module(self, data)
            if is_refresh:
                data.subordinate_input_object.set_select(init_data, True)
            else:
                return init_data

    def pagination_clicked(self, data):
        if data['action'] == 'prev':
            self.page = data['page']
        elif data['action'] == 'next':
            self.page = data['page']
        elif data['action'] == 'per_page':
            self.page_size = data['page']
        self.show_data()

    def search(self, data):
        if isinstance(data, dict):
            self.params = data
            self.show_data()
            success_message(self, '搜索结果展示完成~')
        else:
            self.sub_options(data)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 2024-08-16 17:05
# @Author : 毛鹏

from .mango_div import MangoDiv
from .mango_menu import MangoMenu
from .mango_menu_button import MangoMenuButton

__all__ = [
    'MangoDiv',
    'MangoMenu',
    'MangoMenuButton'
]


# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 2024-08-16 17:05
# @Author : 毛鹏
import os

from PySide6.QtCore import QRect, QEvent, QPoint
from PySide6.QtGui import QColor, Qt, QPainter, QPixmap
from PySide6.QtWidgets import QGraphicsDropShadowEffect, QLabel, QPushButton

from mangoui.settings.settings import THEME


class MangoMenuButton(QPushButton):
    def __init__(
            self,
            app_parent,
            text,
            tooltip_text='',
            url=None,
            btn_id=None,
            icon_path=None,
            is_active=False,
            height=50,
    ):
        super().__init__()
        self.setText(text)
        self.url = url
        self.setCursor(Qt.PointingHandCursor)  # type: ignore
        self.setMaximumHeight(height)
        self.setMinimumHeight(height)
        self.setObjectName(btn_id)

        self._icon_path = icon_path
        self._icon_active_menu = ":/icons/active_menu.svg"

        self._margin = 4

        self._set_icon_color = THEME.text_100
        self._set_bg_color = THEME.bg_300
        self.app_parent = app_parent
        self._is_active = is_active
        self._is_active_tab = False
        self._is_toggle_active = False
        self.tooltip_text = tooltip_text
        self.tooltip = _ToolTip(
            self.app_parent,
            self.tooltip_text,
            THEME.bg_300,
            THEME.text_200,
            THEME.text_100
        )
        self.tooltip.hide()

    def paintEvent(self, event):
        # 画家
        p = QPainter()
        p.begin(self)
        p.setRenderHint(QPainter.Antialiasing)  # type: ignore
        p.setPen(Qt.NoPen)  # type: ignore
        p.setFont(self.font())

        # 矩形
        rect = QRect(4, 5, self.width(), self.height() - 10)
        rect_inside = QRect(4, 5, self.width() - 8, self.height() - 10)
        rect_icon = QRect(0, 0, 50, self.height())
        rect_blue = QRect(4, 5, 20, self.height() - 10)
        rect_inside_active = QRect(7, 5, self.width(), self.height() - 10)
        rect_text = QRect(45, 0, self.width() - 50, self.height())

        if self._is_active or self._is_active_tab:
            # 绘制BG蓝色 dark_four
            p.setBrush(QColor(THEME.accent_200))
            p.drawRoundedRect(rect_blue, 8, 8)

            # BG内部
            p.setBrush(QColor(THEME.bg_100))
            p.drawRoundedRect(rect_inside_active, 8, 8)

            # 绘制活动
            icon_path = self._icon_active_menu
            app_path = os.path.abspath(os.getcwd())
            icon_path = os.path.normpath(os.path.join(app_path, icon_path))
            self._set_icon_color = THEME.text_100
            self.icon_active(p, icon_path, self.width())

            # 绘制文本
            p.setPen(QColor(THEME.text_100))
            p.drawText(rect_text, Qt.AlignVCenter, self.text())  # type: ignore

            # 绘制图标
            self.icon_paint(p, self._icon_path, rect_icon, self._set_icon_color)

        else:
            if self._is_toggle_active:
                # BG内部
                p.setBrush(QColor(THEME.accent_200))
                p.drawRoundedRect(rect_inside, 8, 8)

                # 绘制文本
                p.setPen(QColor(THEME.bg_100))
                p.drawText(rect_text, Qt.AlignVCenter, self.text())  # type: ignore

                # 绘制图标
                if self._is_toggle_active:
                    self.icon_paint(p, self._icon_path, rect_icon, THEME.bg_300)
                else:
                    self.icon_paint(p, self._icon_path, rect_icon, self._set_icon_color)
            else:
                # BG内部
                p.setBrush(QColor(self._set_bg_color))
                p.drawRoundedRect(rect_inside, 8, 8)

                # 绘制文本
                p.setPen(QColor(THEME.text_100))
                p.drawText(rect_text, Qt.AlignVCenter, self.text())  # type: ignore

                # 绘制图标
                self.icon_paint(p, self._icon_path, rect_icon, self._set_icon_color)

        p.end()

    # 设置活动菜单
    def set_active(self, is_active):
        self._is_active = is_active
        if not is_active:
            self._set_icon_color = THEME.text_100
            self._set_bg_color = THEME.bg_300

        self.repaint()

    # 设置活动选项卡菜单
    def set_active_tab(self, is_active):
        self._is_active_tab = is_active
        if not is_active:
            self._set_icon_color = THEME.text_100
            self._set_bg_color = THEME.bg_300

        self.repaint()

    # 如果是活动菜单，则返回
    def is_active(self):
        return self._is_active

    # 如果选项卡菜单处于活动状态，则返回
    def is_active_tab(self):
        return self._is_active_tab

    # 设置活动切换
    def set_active_toggle(self, is_active):
        self._is_toggle_active = is_active

    # 设置图标
    def set_icon(self, icon_path):
        self._icon_path = icon_path
        self.repaint()

    # 用颜色绘制图标
    def icon_paint(self, qp, image, rect, color):
        if image is None:
            # 创建一个空白图像，设置大小为 rect 的大小
            icon = QPixmap(rect.size())
            icon.fill(Qt.transparent)  # type: ignore
        else:
            icon = QPixmap(image)
        painter = QPainter(icon)
        painter.setCompositionMode(QPainter.CompositionMode_SourceIn)  # type: ignore
        painter.fillRect(icon.rect(), color)
        qp.drawPixmap(
            (rect.width() - icon.width()) / 2,
            (rect.height() - icon.height()) / 2,
            icon
        )
        painter.end()

    # 在右侧绘制活动图标
    def icon_active(self, qp, image, width):
        icon = QPixmap(image)
        painter = QPainter(icon)
        painter.setCompositionMode(QPainter.CompositionMode_SourceIn)  # type: ignore
        painter.fillRect(icon.rect(), THEME.bg_100)
        qp.drawPixmap(width - 5, 0, icon)
        painter.end()

    # 更改样式
    def change_style(self, event):
        if event == QEvent.Enter:  # type: ignore
            if not self._is_active:
                self._set_icon_color = THEME.text_200
                self._set_bg_color = THEME.primary_200
            self.repaint()
        elif event == QEvent.Leave:  # type: ignore
            if not self._is_active:
                self._set_icon_color = THEME.text_100
                self._set_bg_color = THEME.bg_300
            self.repaint()
        elif event == QEvent.MouseButtonPress:  # type: ignore
            if not self._is_active:
                self._set_icon_color = THEME.text_100
                self._set_bg_color = THEME.primary_300
            self.repaint()
        elif event == QEvent.MouseButtonRelease:  # type: ignore
            if not self._is_active:
                self._set_icon_color = THEME.text_100
                self._set_bg_color = THEME.bg_300
            self.repaint()

    # 当鼠标位于BTN上时触发的事件
    def enterEvent(self, event):
        self.change_style(QEvent.Enter)  # type: ignore
        if self.width() == 50 and self.tooltip_text:
            self.move_tooltip()
            self.tooltip.show()

    # 鼠标离开BTN时触发的事件
    def leaveEvent(self, event):
        self.change_style(QEvent.Leave)  # type: ignore
        self.tooltip.hide()

    # 按下左键时触发的事件
    def mousePressEvent(self, event):
        if event.button() == Qt.LeftButton:  # type: ignore
            self.change_style(QEvent.MouseButtonPress)  # type: ignore
            self.tooltip.hide()
            return self.clicked.emit()

    # 松开鼠标按钮后触发的事件
    def mouseReleaseEvent(self, event):
        if event.button() == Qt.LeftButton:  # type: ignore
            self.change_style(QEvent.MouseButtonRelease)  # type: ignore
            return self.released.emit()

    def move_tooltip(self):
        gp = self.mapToGlobal(QPoint(0, 0))

        pos = self.app_parent.mapFromGlobal(gp)

        pos_x = pos.x() + self.width() + 5
        pos_y = pos.y() + (self.width() - self.tooltip.height()) // 2

        self.tooltip.move(pos_x, pos_y)


class _ToolTip(QLabel):
    def __init__(
            self,
            parent,
            tooltip,
            dark_one,
            context_color,
            text_foreground
    ):
        QLabel.__init__(self)
        
        style = f"""QLabel {{ background-color: {dark_one}; color: {text_foreground}; padding: 6px 12px; border-radius: {THEME.border_radius}; border: 1px solid {context_color}; font-family: {THEME.font.family}; font-size: {THEME.font.text_size}px; font-weight: 500; }}"""
        self.setObjectName(u"label_tooltip")
        self.setStyleSheet(style)
        self.setMinimumHeight(34)
        self.setParent(parent)
        self.setText(tooltip)
        self.adjustSize()

        self.shadow = QGraphicsDropShadowEffect(self)
        self.shadow.setBlurRadius(30)
        self.shadow.setXOffset(0)
        self.shadow.setYOffset(0)
        self.shadow.setColor(QColor(0, 0, 0, 80))
        self.setGraphicsEffect(self.shadow)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 2024-08-16 17:05
# @Author : 毛鹏
import math

from PySide6.QtCore import *
from PySide6.QtWidgets import *

from mangoui.settings.settings import THEME


class MangoPagination(QWidget):
    click = Signal(object)

    def __init__(self, parent=None):
        super().__init__()
        self.parent = parent
        self.total_size = 0
        self.page = 1
        self.number_part = 20

        self.current_page_label1 = QLabel(f"共 {self.total_size} 条")

        self.prev_icon_button = QPushButton()
        self.prev_icon_button.setMaximumWidth(36)
        self.prev_icon_button.setMinimumHeight(36)
        self.prev_icon_button.setEnabled(False)
        self.prev_icon_button.setText('<')
        self.prev_icon_button.setCursor(Qt.PointingHandCursor)  # type: ignore

        self.next_icon_button = QPushButton()
        self.next_icon_button.setMaximumWidth(36)
        self.next_icon_button.setMinimumHeight(36)
        self.next_icon_button.setText('>')
        self.next_icon_button.setCursor(Qt.PointingHandCursor)  # type: ignore

        # 创建当前页显示的标签
        self.current_page_label = QLabel(f"{self.page}")
        self.current_page_label.setStyleSheet(f"""
            QLabel {{
                color: {THEME.text_100};
                font-family: {THEME.font.family};
                font-size: {THEME.font.text_size}px;
                font-weight: 500;
                padding: 0 8px;
            }}
        """)
        
        self.items_per_page_combo = QComboBox()
        self.items_per_page_combo.addItems(["10 条/页", "20 条/页", "30 条/页", "50 条/页", "100 条/页"])
        self.items_per_page_combo.setCurrentText("20 条/页")
        self.items_per_page_combo.setCursor(Qt.PointingHandCursor)  # type: ignore

        # 布局设置
        layout = QHBoxLayout()
        layout.setContentsMargins(0, 0, 0, 0)
        layout.addStretch()
        layout.addWidget(self.current_page_label1)
        layout.addWidget(self.prev_icon_button)
        layout.addWidget(self.current_page_label)
        layout.addWidget(self.next_icon_button)
        layout.addWidget(self.items_per_page_combo)

        self.setLayout(layout)
        
        # 设置样式
        self.set_stylesheet()

        self.prev_icon_button.clicked.connect(self.on_prev_page)
        self.next_icon_button.clicked.connect(self.on_next_page)

        self.items_per_page_combo.currentIndexChanged.connect(self.on_items_per_page_changed)
        self.button_enabled()

    def on_prev_page(self):
        self.page -= 1
        self.click.emit({'action': 'prev', 'page': self.page})
        self.current_page_label.setText(str(self.page))
        self.button_enabled()

    def on_next_page(self):
        self.page += 1
        self.click.emit({'action': 'next', 'page': self.page})
        self.current_page_label.setText(str(self.page))
        self.button_enabled()

    def on_items_per_page_changed(self, index):
        selected_text = self.items_per_page_combo.itemText(index)
        self.number_part = int(selected_text.split(" ")[0])
        self.click.emit({'action': 'per_page', 'page': self.number_part})
        self.button_enabled()

    def set_total_size(self, total_size: str):
        self.current_page_label1.setText(f"共 {total_size} 条")
        if total_size:
            self.total_size = int(total_size)
        self.button_enabled()

    def button_enabled(self):
        if self.page > 1:
            self.prev_icon_button.setEnabled(True)
        else:
            self.prev_icon_button.setEnabled(False)
        if self.page >= math.ceil(self.total_size / self.number_part):
            self.next_icon_button.setEnabled(False)
        else:
            self.next_icon_button.setEnabled(True)
            
    def set_stylesheet(self):
        # 设置按钮样式
        button_style = f"""
        QPushButton {{
            background-color: {THEME.bg_100};
            border: 1px solid {THEME.bg_300};
            border-radius: {THEME.border_radius};
            color: {THEME.text_100};
            font-family: {THEME.font.family};
            font-size: {THEME.font.text_size}px;
            font-weight: 500;
            padding: 6px 12px;
        }}
        QPushButton:hover {{
            background-color: {THEME.primary_200};
            border: 1px solid {THEME.primary_100};
        }}
        QPushButton:pressed {{
            background-color: {THEME.primary_300};
        }}
        QPushButton:disabled {{
            background-color: {THEME.bg_200};
            color: {THEME.text_200};
            border: 1px solid {THEME.bg_300};
        }}
        """
        
        self.prev_icon_button.setStyleSheet(button_style)
        self.next_icon_button.setStyleSheet(button_style)
        
        # 设置标签样式
        label_style = f"""
        QLabel {{
            color: {THEME.text_100};
            font-family: {THEME.font.family};
            font-size: {THEME.font.text_size}px;
            padding: 0 8px;
        }}
        """
        
        self.current_page_label1.setStyleSheet(label_style)
        
        # 设置下拉框样式
        combo_style = f"""
        QComboBox {{
            background-color: {THEME.bg_100};
            border-radius: {THEME.border_radius};
            border: 1px solid {THEME.bg_300};
            padding: 6px 12px;
            padding-right: 30px;
            selection-color: white;
            selection-background-color: {THEME.primary_100};
            color: {THEME.text_100};
            font-family: {THEME.font.family};
            font-size: {THEME.font.text_size}px;
            outline: none;
            min-width: 100px;
        }}
        
        QComboBox:focus {{
            border: 1px solid {THEME.primary_100};
        }}
        
        QComboBox::drop-down {{
            border: none;
            background-color: transparent;
            width: 20px;
            height: 20px;
            right: 6px;
            top: 50%;
            transform: translateY(-50%);
        }}
        
        QComboBox QAbstractItemView {{
            background-color: {THEME.bg_100};
            border: 1px solid {THEME.bg_300};
            border-radius: {THEME.border_radius};
            selection-background-color: {THEME.primary_200};
            selection-color: {THEME.text_100};
            outline: none;
        }}
        
        QComboBox QAbstractItemView::item {{
            padding: 6px 12px;
            color: {THEME.text_100};
        }}
        
        QComboBox QAbstractItemView::item:selected {{
            background-color: {THEME.primary_200};
        }}
        """
        
        self.items_per_page_combo.setStyleSheet(combo_style)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2025-01-28 16:03
# @Author : 毛鹏
from PySide6.QtWidgets import QApplication


def generate_qss(theme):
    return """
        /* ==========================================
           全新现代化样式系统 v2.0
           设计理念：优雅、现代、直观
        ========================================== */
        
        /* 全局样式重置和基础样式 */
        * {
            box-sizing: border-box;
        }
        
        /* 主窗口样式 */
        QMainWindow {
            background: qlineargradient(x1: 0, y1: 0, x2: 1, y2: 1, stop: 0 %(neutral_50)s, stop: 1 %(neutral_100)s);
            font-family: %(font_family)s;
            color: %(text_100)s;
            font-size: %(font_size_base)s;
        }
        
        /* 图表组件样式 */
        MangoLinePlot#mango_line_plot {
            background: %(bg_100)s;
            border-radius: %(radius_lg)s;
            padding: %(spacing_3)s;
            border: %(border)s;
        }
        
        MangoPiePlot#mango_pie_plot {
            background: %(bg_100)s;
            border-radius: %(radius_lg)s;
            padding: %(spacing_3)s;
            border: %(border)s;
        }

        /* 卡片组件样式 */
        MangoCard#mango_card {
            background-color: %(bg_100)s;
            border: %(border)s;
            border-radius: %(radius_xl)s;
            padding: %(spacing_4)s;
        }
        
        MangoCard#mango_card > QFrame {
            background-color: %(bg_100)s;
            border: %(border)s;
            border-radius: %(radius_xl)s;
            padding: %(spacing_4)s;
        }
        
        /* 标签组件样式 */
        MangoLabel#mango_label {
            background-color: transparent;
            color: %(text_100)s;
            font-family: %(font_family)s;
            font-size: %(font_size_base)s;
        }

        /* 表格组件样式 */
        MangoTable#mango_table {
            background-color: %(bg_100)s;
            padding: %(spacing_0)s;
            border-radius: %(radius_lg)s;
            color: %(text_100)s;
            border: %(border)s;
            alternate-background-color: %(bg_200)s;
            selection-background-color: %(primary_500)s;
            selection-color: white;
            gridline-color: %(bg_300)s;
        }
        
        MangoTable#mango_table::item {
            border: none;
            padding: %(spacing_2)s %(spacing_3)s;
            border-bottom: %(border)s;
        }
        
        MangoTable#mango_table::item:selected {
            background-color: %(primary_500)s;
            color: white;
        }

        MangoTable#mango_table QHeaderView::section {
            background-color: %(bg_200)s;
            border: none;
            border-bottom: 1px solid %(bg_300)s;
            padding: %(spacing_2)s %(spacing_3)s;
            font-weight: %(font_weight_semibold)s;
            color: %(text_100)s;
            font-size: %(font_size_sm)s;
        }
        
        MangoTable#mango_table QHeaderView::section:hover {
            background-color: %(bg_300)s;
        }
        
        MangoTable#mango_table::horizontalHeader {
            background-color: %(bg_200)s;
        }
        
        MangoTable#mango_table QTableCornerButton::section {
            border: none;
            background-color: %(bg_200)s;
            border-top-left-radius: %(radius_lg)s;
        }
        
        MangoTable#mango_table QHeaderView::section:horizontal {
            border: none;
            background-color: %(bg_200)s;
            padding: %(spacing_2)s %(spacing_3)s;
        }
        
        MangoTable#mango_table QHeaderView::section:vertical {
            border: none;
            background-color: %(bg_200)s;
            padding: %(spacing_2)s %(spacing_3)s;
            border-bottom: %(border)s;
        }

        /* 滚动条样式 */
        QScrollBar:horizontal {
            border: none;
            background: %(bg_100)s;
            height: 10px;
            margin: 0px 21px 0 21px;
            border-radius: 5px;
        }
        
        QScrollBar::handle:horizontal {
            background: %(bg_300)s;
            min-width: 25px;
            border-radius: 5px;
        }
        
        QScrollBar::add-line:horizontal {
            border: none;
            background: %(bg_300)s;
            width: 20px;
            border-top-right-radius: 5px;
            border-bottom-right-radius: 5px;
            subcontrol-position: right;
            subcontrol-origin: margin;
        }
        
        QScrollBar::sub-line:horizontal {
            border: none;
            background: %(bg_300)s;
            width: 20px;
            border-top-left-radius: 5px;
            border-bottom-left-radius: 5px;
            subcontrol-position: left;
            subcontrol-origin: margin;
        }
        
        QScrollBar::up-arrow:horizontal, QScrollBar::down-arrow:horizontal {
            background: none;
        }
        
        QScrollBar::add-page:horizontal, QScrollBar::sub-page:horizontal {
            background: none;
        }

        QScrollBar:vertical {
            border: none;
            background: %(bg_100)s;
            width: 10px;
            margin: 21px 0 21px 0;
            border-radius: 5px;
        }
        
        QScrollBar::handle:vertical {
            background: %(bg_300)s;
            min-height: 25px;
            border-radius: 5px;
        }
        
        QScrollBar::add-line:vertical {
            border: none;
            background: %(bg_300)s;
            height: 20px;
            border-bottom-left-radius: 5px;
            border-bottom-right-radius: 5px;
            subcontrol-position: bottom;
            subcontrol-origin: margin;
        }
        
        QScrollBar::sub-line:vertical {
            border: none;
            background: %(bg_300)s;
            height: 20px;
            border-top-left-radius: 5px;
            border-top-right-radius: 5px;
            subcontrol-position: top;
            subcontrol-origin: margin;
        }
        
        QScrollBar::up-arrow:vertical, QScrollBar::down-arrow:vertical {
            background: none;
        }
        
        QScrollBar::add-page:vertical, QScrollBar::sub-page:vertical {
            background: none;
        }
        
        /* 时间编辑器样式 */
        MangoTimeEdit#mango_time_edit {
            background-color: %(bg_100)s;
            border-radius: %(radius)s;
            border: %(border)s;
            padding: %(spacing_2)s %(spacing_3)s;
            selection-color: white;
            selection-background-color: %(primary_500)s;
            color: %(text_100)s;
            font-family: %(font_family)s;
            font-size: %(font_size_base)s;
        }
        
        MangoTimeEdit#mango_time_edit:focus {
            border: 1px solid %(primary_500)s;
            background-color: %(bg_100)s;
        }
        
        MangoTimeEdit::up-button, MangoTimeEdit::down-button {
            border: none;
            background: transparent;
            width: 0;
            height: 0;
            margin: 0;
            padding: 0;
        }
        
        /* 级联选择器样式 */
        MangoCascade#mango_cascade {
            background-color: %(bg_100)s;
            border-radius: %(radius_full)s;
            border: %(border)s;
            padding: %(spacing_2)s %(spacing_4)s;
            color: %(text_100)s;
            font-family: %(font_family)s;
            font-size: %(font_size_base)s;
            font-weight: %(font_weight_semibold)s;
            transition: all 0.3s cubic-bezier(0.4, 0, 0.2, 1);
        }

        MangoCascade#mango_cascade:focus {
            border: 1px solid %(primary_500)s;
            background-color: %(bg_100)s;
        }

        MangoCascade#mango_cascade::menu-indicator {
            image: url(:/icons/down.svg);
        }
        
        MangoCascade#mango_cascade QMenu {
            background-color: %(bg_100)s;
            border: %(border)s;
            border-radius: %(radius_lg)s;
            padding: %(spacing_1)s;
        }

        MangoCascade#mango_cascade QMenu::item {
            padding: %(spacing_2)s %(spacing_3)s;
            color: %(text_100)s;
            border-radius: %(radius_sm)s;
        }

        MangoCascade#mango_cascade QMenu::item:selected {
            background-color: %(primary_100)s;
            color: %(text_100)s;
        }
        
        /* 组合框样式 */
        MangoComboBoxMany#mango_combo_box_many {
            background-color: %(bg_100)s;
            border-radius: %(radius)s;
            border: %(border)s;
            padding: %(spacing_2)s %(spacing_3)s;
            selection-color: white;
            selection-background-color: %(primary_500)s;
            color: %(text_100)s;
            font-family: %(font_family)s;
            font-size: %(font_size_base)s;
        }
        
        MangoComboBoxMany#mango_combo_box_many:focus {
            border: 1px solid %(primary_500)s;
            background-color: %(bg_100)s;
        }
        
        MangoComboBoxMany#mango_combo_box_many::drop-down {
            border: none;
            background-color: transparent;
            background-image: url(:/icons/down.svg);
            background-repeat: no-repeat;
            background-position: center;
            width: 20px;
        }
        
        MangoComboBox#mango_combo_box {
            background-color: %(bg_100)s;
            border-radius: %(radius)s;
            border: %(border)s;
            padding: %(spacing_2)s %(spacing_3)s;
            selection-color: white;
            selection-background-color: %(primary_500)s;
            color: %(text_100)s;
            font-family: %(font_family)s;
            font-size: %(font_size_base)s;
        }
        
        MangoComboBox#mango_combo_box:focus {
            border: 1px solid %(primary_500)s;
            background-color: %(bg_100)s;
        }
        
        MangoComboBox#mango_combo_box::drop-down {
            border: none;
            background-color: transparent;
            background-image: url(:/icons/down.svg);
            background-repeat: no-repeat;
            background-position: center;
            width: 20px;
        }
        
        /* 文本输入框样式 */
        MangoLineEdit#mango_line_edit {
            background-color: %(bg_100)s;
            border-radius: %(radius)s;
            border: %(border)s;
            padding: %(spacing_2)s %(spacing_3)s;
            selection-color: white;
            selection-background-color: %(primary_500)s;
            color: %(text_100)s;
            font-family: %(font_family)s;
            font-size: %(font_size_base)s;
        }
        
        MangoLineEdit#mango_line_edit:focus {
            border: 1px solid %(primary_500)s;
            background-color: %(bg_100)s;
        }
        
        /* 按钮样式 */
        QPushButton#mango_push_button {
            border: %(border)s;
            color: %(text_100)s;
            border-radius: %(radius_full)s;
            background: qlineargradient(x1: 0, y1: 0, x2: 1, y2: 1, stop: 0 %(neutral_50)s, stop: 1 %(neutral_100)s);
            padding: %(spacing_2)s %(spacing_4)s;
            font-family: %(font_family)s;
            font-size: %(font_size_base)s;
            font-weight: %(font_weight_semibold)s;
            transition: all 0.3s cubic-bezier(0.4, 0, 0.2, 1);
        }
        
        QPushButton#mango_push_button:hover {
            background: qlineargradient(x1: 0, y1: 0, x2: 1, y2: 1, stop: 0 %(neutral_100)s, stop: 1 %(neutral_200)s);
            border: 1px solid %(primary_300)s;
            color: %(neutral_900)s;
            transform: translateY(-1px);
        }
        
        QPushButton#mango_push_button:pressed {
            background: %(primary_500)s;
            color: white;
            border: 1px solid %(primary_500)s;
            transform: translateY(0);
        }
        
        QPushButton#mango_push_button:disabled {
            background: %(neutral_100)s;
            color: %(neutral_400)s;
            border: 1px solid %(neutral_200)s;
            transform: none;
        }
        
        /* 主要按钮样式 */
        QPushButton#mango_push_button.primary {
            background: %(gradient_primary)s;
            color: white;
            border: none;
        }
        
        QPushButton#mango_push_button.primary:hover {
            background: qlineargradient(x1: 0, y1: 0, x2: 1, y2: 1, stop: 0 %(primary_600)s, stop: 1 %(primary_700)s);
            border: none;
            transform: translateY(-2px);
        }
        
        QPushButton#mango_push_button.primary:pressed {
            background: %(primary_700)s;
            transform: translateY(0);
        }
        
        /* 成功按钮样式 */
        QPushButton#mango_push_button.success {
            background: %(gradient_success)s;
            color: white;
            border: none;
        }
        
        QPushButton#mango_push_button.success:hover {
            background: qlineargradient(x1: 0, y1: 0, x2: 1, y2: 1, stop: 0 %(success_600)s, stop: 1 %(success_700)s);
            border: none;
            transform: translateY(-2px);
        }
        
        QPushButton#mango_push_button.success:pressed {
            background: %(success_700)s;
            transform: translateY(0);
        }
        
        /* 危险按钮样式 */
        QPushButton#mango_push_button.danger {
            background: %(gradient_danger)s;
            color: white;
            border: none;
        }
        
        QPushButton#mango_push_button.danger:hover {
            background: qlineargradient(x1: 0, y1: 0, x2: 1, y2: 1, stop: 0 %(danger_600)s, stop: 1 %(danger_700)s);
            border: none;
            transform: translateY(-2px);
        }
        
        QPushButton#mango_push_button.danger:pressed {
            background: %(danger_700)s;
            transform: translateY(0);
        }
        
        /* 文本编辑器样式 */
        MangoTextEdit#mango_text_edit {
            background-color: %(bg_100)s;
            border-radius: %(radius)s;
            border: %(border)s;
            padding: %(spacing_2)s;
            selection-color: white;
            selection-background-color: %(primary_500)s;
            color: %(text_100)s;
            font-family: %(font_family)s;
            font-size: %(font_size_base)s;
        }
        
        MangoTextEdit#mango_text_edit:focus {
            border: 1px solid %(primary_500)s;
            background-color: %(bg_100)s;
        }
        
        /* 标签页样式 */
        MangoTabs#mango_tabs {
            background-color: %(bg_100)s;
            border-radius: %(radius_lg)s;
            border: %(border)s;
            padding: %(spacing_2)s;
        }
        
        /* 对话框样式 */
        MangoDialog#mango_dialog {
            background-color: %(bg_100)s;
            border-radius: %(radius_xl)s;
            border: %(border)s;
        }
        
        MangoDialog#mango_dialog::title {
            background-color: %(bg_100)s;
            color: %(text_100)s;
            border-bottom: %(border)s;
            padding: %(spacing_3)s;
            font-weight: %(font_weight_bold)s;
            font-size: %(font_size_lg)s;
        }
        
        /* 树形控件样式 */
        MangoTree#mango_tree {
            background-color: %(bg_100)s;
            border-radius: %(radius)s;
            border: %(border)s;
            color: %(text_100)s;
            font-family: %(font_family)s;
            font-size: %(font_size_base)s;
            padding: %(spacing_2)s;
        }
    
        MangoTree#mango_tree::item {
            padding: %(spacing_2)s %(spacing_3)s;
            border-radius: %(radius_sm)s;
        }
    
        MangoTree#mango_tree::item:selected {
            background-color: %(primary_100)s;
            color: %(text_100)s;
        }
        
        MangoTree#mango_tree::item:hover {
            background-color: %(bg_200)s;
        }
        
        /* 滑块样式 */
        QSlider::groove:horizontal {
            border: 1px solid %(bg_300)s;
            height: 4px;
            background: %(bg_200)s;
            border-radius: 2px;
        }
        
        QSlider::handle:horizontal {
            background: %(primary_500)s;
            border: 1px solid %(primary_700)s;
            width: 18px;
            height: 18px;
            border-radius: 9px;
            margin: -7px 0;
        }
        
        QSlider::sub-page:horizontal {
            background: %(primary_300)s;
            border-radius: 2px;
        }
        
        /* 复选框样式 */
        QCheckBox {
            color: %(text_100)s;
            font-family: %(font_family)s;
            font-size: %(font_size_base)s;
            spacing: %(spacing_2)s;
        }
        
        QCheckBox::indicator {
            width: 16px;
            height: 16px;
            border: 1px solid %(bg_300)s;
            background-color: %(bg_100)s;
            border-radius: %(radius_sm)s;
        }
        
        QCheckBox::indicator:checked {
            background-color: %(primary_500)s;
            border: 1px solid %(primary_500)s;
        }
        
        QCheckBox::indicator:checked:after {
            content: "";
            position: absolute;
            width: 4px;
            height: 8px;
            border: 1px solid white;
            border-left: 0;
            border-top: 0;
            transform: rotate(45deg);
            left: 4px;
            top: 1px;
        }
        
        /* 单选按钮样式 */
        QRadioButton {
            color: %(text_100)s;
            font-family: %(font_family)s;
            font-size: %(font_size_base)s;
            spacing: %(spacing_2)s;
        }
        
        QRadioButton::indicator {
            width: 16px;
            height: 16px;
            border: 1px solid %(bg_300)s;
            background-color: %(bg_100)s;
            border-radius: 8px;
        }
        
        QRadioButton::indicator:checked {
            background-color: %(primary_500)s;
            border: 1px solid %(primary_500)s;
        }
        
        QRadioButton::indicator:checked:after {
            content: "";
            position: absolute;
            width: 6px;
            height: 6px;
            background-color: white;
            border-radius: 3px;
            left: 5px;
            top: 5px;
        }
        
        /* 进度条样式 */
        QProgressBar {
            border: %(border)s;
            border-radius: %(radius)s;
            background-color: %(bg_200)s;
            text-align: center;
            color: %(text_100)s;
            font-size: %(font_size_xs)s;
        }
        
        QProgressBar::chunk {
            background-color: %(primary_500)s;
            border-radius: %(radius_sm)s;
        }
        
        /* 工具提示样式 */
        QToolTip {
            background-color: %(neutral_800)s;
            color: white;
            border: none;
            border-radius: %(radius_sm)s;
            padding: %(spacing_1)s %(spacing_2)s;
            font-family: %(font_family)s;
            font-size: %(font_size_xs)s;
        }
    """ % {
        # 主色调
        'primary_50': theme.primary_50,
        'primary_100': theme.primary_100,
        'primary_200': theme.primary_200,
        'primary_300': theme.primary_300,
        'primary_400': theme.primary_400,
        'primary_500': theme.primary_500,
        'primary_600': theme.primary_600,
        'primary_700': theme.primary_700,
        'primary_800': theme.primary_800,
        'primary_900': theme.primary_900,
        
        # 成功色
        'success_50': theme.success_50,
        'success_100': theme.success_100,
        'success_200': theme.success_200,
        'success_300': theme.success_300,
        'success_400': theme.success_400,
        'success_500': theme.success_500,
        'success_600': theme.success_600,
        'success_700': theme.success_700,
        'success_800': theme.success_800,
        'success_900': theme.success_900,
        
        # 警告色
        'warning_50': theme.warning_50,
        'warning_100': theme.warning_100,
        'warning_200': theme.warning_200,
        'warning_300': theme.warning_300,
        'warning_400': theme.warning_400,
        'warning_500': theme.warning_500,
        'warning_600': theme.warning_600,
        'warning_700': theme.warning_700,
        'warning_800': theme.warning_800,
        'warning_900': theme.warning_900,
        
        # 危险色
        'danger_50': theme.danger_50,
        'danger_100': theme.danger_100,
        'danger_200': theme.danger_200,
        'danger_300': theme.danger_300,
        'danger_400': theme.danger_400,
        'danger_500': theme.danger_500,
        'danger_600': theme.danger_600,
        'danger_700': theme.danger_700,
        'danger_800': theme.danger_800,
        'danger_900': theme.danger_900,
        
        # 中性色
        'neutral_50': theme.neutral_50,
        'neutral_100': theme.neutral_100,
        'neutral_200': theme.neutral_200,
        'neutral_300': theme.neutral_300,
        'neutral_400': theme.neutral_400,
        'neutral_500': theme.neutral_500,
        'neutral_600': theme.neutral_600,
        'neutral_700': theme.neutral_700,
        'neutral_800': theme.neutral_800,
        'neutral_900': theme.neutral_900,
        
        # 渐变色
        'gradient_primary': theme.gradient_primary,
        'gradient_success': theme.gradient_success,
        'gradient_danger': theme.gradient_danger,
        
        # 圆角
        'radius_none': theme.radius_none,
        'radius_sm': theme.radius_sm,
        'radius': theme.radius,
        'radius_md': theme.radius_md,
        'radius_lg': theme.radius_lg,
        'radius_xl': theme.radius_xl,
        'radius_2xl': theme.radius_2xl,
        'radius_3xl': theme.radius_3xl,
        'radius_full': theme.radius_full,
        
        # 间距
        'spacing_0': theme.spacing_0,
        'spacing_1': theme.spacing_1,
        'spacing_2': theme.spacing_2,
        'spacing_3': theme.spacing_3,
        'spacing_4': theme.spacing_4,
        'spacing_5': theme.spacing_5,
        'spacing_6': theme.spacing_6,
        'spacing_8': theme.spacing_8,
        'spacing_10': theme.spacing_10,
        'spacing_12': theme.spacing_12,
        
        # 字体大小
        'font_size_xs': theme.font_size_xs,
        'font_size_sm': theme.font_size_sm,
        'font_size_base': theme.font_size_base,
        'font_size_lg': theme.font_size_lg,
        'font_size_xl': theme.font_size_xl,
        'font_size_2xl': theme.font_size_2xl,
        'font_size_3xl': theme.font_size_3xl,
        
        # 字体粗细
        'font_weight_normal': theme.font_weight_normal,
        'font_weight_medium': theme.font_weight_medium,
        'font_weight_semibold': theme.font_weight_semibold,
        'font_weight_bold': theme.font_weight_bold,
        
        # 行高
        'line_height_normal': theme.line_height_normal,
        'line_height_tight': theme.line_height_tight,
        
        # 原有变量保持兼容
        'text_100': theme.text_100,
        'text_200': theme.text_200,
        'bg_100': theme.bg_100,
        'bg_200': theme.bg_200,
        'bg_300': theme.bg_300,
        'border': theme.border,
        'border_radius': theme.border_radius,
        'font_family': theme.font.family
    }


# 切换主题
def apply_theme(theme):
    qss_style = generate_qss(theme)
    app: QApplication = QApplication.instance()  # type: ignore
    if app is not None:
        app.setStyleSheet(qss_style)


# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: LCD数字显示组件
# @Time   : 2025-11-25 11:15
# @Author : Qwen

from PySide6.QtCore import *
from PySide6.QtWidgets import *
from mangoui.settings.settings import THEME


class MangoLCDNumber(QLCDNumber):
    def __init__(self, parent=None, **kwargs):
        super().__init__(parent)
        self.kwargs = kwargs
        self.setSegmentStyle(QLCDNumber.Filled)  # type: ignore
        self.set_stylesheet()
        
    def set_stylesheet(self):
        style = f"""
        QLCDNumber {{
            background-color: {THEME.bg_100};
            border-radius: {THEME.border_radius};
            border: 1px solid {THEME.bg_300};
            color: {THEME.primary_100};
        }}

        QLCDNumber:disabled {{
            background-color: {THEME.bg_200};
            color: {THEME.text_200};
        }}
        """
        self.setStyleSheet(style)


# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-11-02 21:24
# @Author : 毛鹏

from PySide6.QtCore import *
from PySide6.QtGui import *
from PySide6.QtWidgets import *

# 从具体的组件模块中导入所需的组件
from mangoui.widgets.menu import (
    MangoTabs, MangoMenuBar, MangoToolBar
)
from mangoui.widgets.layout import MangoVBoxLayout, MangoGridLayout


class MenuPage(QWidget):
    def __init__(self, parent):
        super().__init__()
        self.parent = parent
        self.layout = MangoVBoxLayout(self)
        
        # 创建滚动区域以容纳所有组件
        self.scroll_area = QScrollArea()
        self.scroll_area.setWidgetResizable(True)
        self.scroll_widget = QWidget()
        self.scroll_layout = MangoVBoxLayout(self.scroll_widget)
        
        # 标题
        title = QLabel("菜单组件展示")
        title.setStyleSheet("font-size: 18px; font-weight: bold; margin: 10px 0;")
        self.scroll_layout.addWidget(title)

        # 使用网格布局组织菜单组件，提高空间利用率
        self.components_grid = MangoGridLayout()
        self.components_grid.setColumnStretch(1, 1)
        
        # 选项卡组件（原有）
        self.mango_tabs = MangoTabs()
        self.mango_tabs.add_tab("标签页1", QLabel("标签页1内容"))
        self.mango_tabs.add_tab("标签页2", QLabel("标签页2内容"))
        self.mango_tabs.add_tab("标签页3", QLabel("标签页3内容"))
        self.components_grid.addWidget(QLabel("选项卡:"), 0, 0)
        self.components_grid.addWidget(self.mango_tabs, 0, 1)

        # 菜单栏组件
        self.mango_menu_bar = MangoMenuBar()
        file_menu = self.mango_menu_bar.addMenu("文件")
        edit_menu = self.mango_menu_bar.addMenu("编辑")
        help_menu = self.mango_menu_bar.addMenu("帮助")
        
        # 文件菜单项
        new_action = file_menu.addAction("新建")
        open_action = file_menu.addAction("打开")
        save_action = file_menu.addAction("保存")
        file_menu.addSeparator()
        exit_action = file_menu.addAction("退出")
        
        # 编辑菜单项
        undo_action = edit_menu.addAction("撤销")
        redo_action = edit_menu.addAction("重做")
        edit_menu.addSeparator()
        cut_action = edit_menu.addAction("剪切")
        copy_action = edit_menu.addAction("复制")
        paste_action = edit_menu.addAction("粘贴")
        
        # 帮助菜单项
        about_action = help_menu.addAction("关于")
        
        self.components_grid.addWidget(QLabel("菜单栏:"), 1, 0)
        self.components_grid.addWidget(self.mango_menu_bar, 1, 1)

        # 工具栏组件
        self.mango_tool_bar = MangoToolBar("工具栏")
        self.mango_tool_bar.addAction("新建", lambda: print("新建"))
        self.mango_tool_bar.addAction("打开", lambda: print("打开"))
        self.mango_tool_bar.addAction("保存", lambda: print("保存"))
        self.mango_tool_bar.addSeparator()
        self.mango_tool_bar.addAction("剪切", lambda: print("剪切"))
        self.mango_tool_bar.addAction("复制", lambda: print("复制"))
        self.mango_tool_bar.addAction("粘贴", lambda: print("粘贴"))
        
        self.components_grid.addWidget(QLabel("工具栏:"), 2, 0)
        self.components_grid.addWidget(self.mango_tool_bar, 2, 1)
        
        self.scroll_layout.addLayout(self.components_grid)

        # 设置滚动区域
        self.scroll_area.setWidget(self.scroll_widget)
        self.layout.addWidget(self.scroll_area)


# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 工具栏组件
# @Time   : 2025-11-25 11:05
# @Author : Qwen

from PySide6.QtCore import *
from PySide6.QtWidgets import *
from mangoui.settings.settings import THEME


class MangoToolBar(QToolBar):
    def __init__(self, title="", parent=None, **kwargs):
        super().__init__(title, parent)
        self.kwargs = kwargs
        self.set_stylesheet()
        
    def set_stylesheet(self):
        style = f"""
        QToolBar {{
            background-color: {THEME.bg_100};
            border: 1px solid {THEME.bg_300};
            border-radius: {THEME.border_radius};
            padding: 4px;
            spacing: 4px;
        }}

        QToolBar:disabled {{
            background-color: {THEME.bg_200};
        }}

        QToolBar QToolButton {{
            background-color: {THEME.bg_100};
            border: 1px solid {THEME.bg_300};
            border-radius: {THEME.border_radius};
            padding: 6px 10px;
            color: {THEME.text_100};
            font-family: {THEME.font.family};
            font-size: {THEME.font.text_size}px;
        }}

        QToolBar QToolButton:hover {{
            background-color: {THEME.bg_200};
            border: 1px solid {THEME.primary_100};
        }}

        QToolBar QToolButton:pressed {{
            background-color: {THEME.primary_100};
            color: white;
        }}

        QToolBar QToolButton:checked {{
            background-color: {THEME.primary_200};
            color: white;
        }}

        QToolBar QToolButton:disabled {{
            background-color: {THEME.bg_200};
            color: {THEME.text_200};
        }}

        QToolBar::separator {{
            width: 1px;
            background-color: {THEME.bg_300};
            margin: 2px;
        }}

        QToolBar::handle {{
            background-color: {THEME.bg_300};
            border: 1px solid {THEME.bg_200};
            border-radius: 2px;
        }}
        """
        self.setStyleSheet(style)


# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-11-02 21:24
# @Author : 毛鹏

from PySide6.QtCore import *
from PySide6.QtGui import *
from PySide6.QtWidgets import *

# 从具体的组件模块中导入所需的组件
from mangoui.widgets.window import (
    MangoDialog, MangoFrame, MangoTree
)
from mangoui.widgets.input import MangoPushButton
from mangoui.widgets.layout import MangoVBoxLayout, MangoGridLayout


class WindowPage(QWidget):
    def __init__(self, parent):
        super().__init__()
        self.parent = parent
        self.layout = MangoVBoxLayout(self)
        
        # 创建滚动区域以容纳所有组件
        self.scroll_area = QScrollArea()
        self.scroll_area.setWidgetResizable(True)
        self.scroll_widget = QWidget()
        self.scroll_layout = MangoVBoxLayout(self.scroll_widget)
        
        # 标题
        title = QLabel("窗口组件展示")
        title.setStyleSheet("font-size: 18px; font-weight: bold; margin: 10px 0;")
        self.scroll_layout.addWidget(title)

        # 使用网格布局组织窗口组件，提高空间利用率
        self.components_grid = MangoGridLayout()
        self.components_grid.setColumnStretch(1, 1)
        
        # 对话框组件
        dialog_btn = MangoPushButton("打开对话框")
        dialog_btn.clicked.connect(self.show_dialog)
        self.components_grid.addWidget(QLabel("对话框:"), 0, 0)
        self.components_grid.addWidget(dialog_btn, 0, 1)

        # 框架组件
        self.mango_frame = MangoFrame(self)
        frame_layout = MangoVBoxLayout(self.mango_frame)
        frame_layout.addWidget(QLabel("框架内容"))
        self.components_grid.addWidget(QLabel("框架:"), 1, 0)
        self.components_grid.addWidget(self.mango_frame, 1, 1)

        # 树组件
        self.mango_tree = MangoTree("树组件标题")
        tree_layout = MangoVBoxLayout(self.mango_tree)
        tree_layout.addWidget(QLabel("树组件内容"))
        self.components_grid.addWidget(QLabel("树组件:"), 2, 0)
        self.components_grid.addWidget(self.mango_tree, 2, 1)
        
        self.scroll_layout.addLayout(self.components_grid)

        # 设置滚动区域
        self.scroll_area.setWidget(self.scroll_widget)
        self.layout.addWidget(self.scroll_area)

    def show_dialog(self):
        dialog = MangoDialog(self)
        dialog.setWindowTitle("测试对话框")
        layout = MangoVBoxLayout(dialog)
        layout.addWidget(QLabel("这是一个测试对话框"))
        ok_btn = MangoPushButton("确定")
        ok_btn.clicked.connect(dialog.accept)
        layout.addWidget(ok_btn)
        dialog.exec()


# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-08-28 16:33
# @Author : 毛鹏

from PySide6.QtCore import *
from PySide6.QtGui import *
from PySide6.QtWidgets import *

# 从具体的组件模块中导入所需的组件
from mangoui.widgets.window import MangoScrollArea
from mangoui.widgets.container import MangoCard
from mangoui.widgets.layout import MangoVBoxLayout, MangoGridLayout


class ComponentPage(QWidget):
    def __init__(self, parent):
        super().__init__()
        self.parent = parent
        self.layout = MangoVBoxLayout(self)
        
        # 创建滚动区域以容纳所有组件
        self.scroll_area = QScrollArea()
        self.scroll_area.setWidgetResizable(True)
        self.scroll_widget = QWidget()
        self.scroll_layout = MangoVBoxLayout(self.scroll_widget)
        
        # 标题
        title = QLabel("公共组件展示")
        title.setStyleSheet("font-size: 18px; font-weight: bold; margin: 10px 0;")
        self.scroll_layout.addWidget(title)

        # 使用网格布局组织公共组件，提高空间利用率
        self.components_grid = MangoGridLayout()
        self.components_grid.setColumnStretch(1, 1)
        
        # 页面标题和描述
        self.title_label = QLabel(self.scroll_widget)
        self.title_label.setText("页面组件")
        self.title_label.setMaximumSize(QSize(16777215, 40))
        font = QFont()
        font.setPointSize(16)
        self.title_label.setFont(font)
        self.title_label.setStyleSheet("font-size: 16pt")
        self.title_label.setAlignment(Qt.AlignCenter)
        self.components_grid.addWidget(self.title_label, 0, 0, 1, 2)
        
        self.description_label = QLabel(self.scroll_widget)
        self.description_label.setAlignment(Qt.AlignHCenter | Qt.AlignTop)
        self.description_label.setText("以下是所有自定义小部件\n哈哈哈哈哈")
        self.description_label.setWordWrap(True)
        self.components_grid.addWidget(self.description_label, 1, 0, 1, 2)

        # 滚动区域组件
        self.scroll_area_content = MangoScrollArea()
        content_widget = QWidget()
        content_layout = MangoVBoxLayout(content_widget)
        content_layout.addWidget(QLabel("滚动区域内容1"))
        content_layout.addWidget(QLabel("滚动区域内容2"))
        content_layout.addWidget(QLabel("滚动区域内容3"))
        content_layout.addWidget(QLabel("滚动区域内容4"))
        content_layout.addWidget(QLabel("滚动区域内容5"))
        self.scroll_area_content.setWidget(content_widget)
        self.components_grid.addWidget(QLabel("滚动区域:"), 2, 0)
        self.components_grid.addWidget(self.scroll_area_content, 2, 1)
        
        self.scroll_layout.addLayout(self.components_grid)

        # 设置滚动区域
        self.scroll_area.setWidget(self.scroll_widget)
        self.layout.addWidget(self.scroll_area)

    def load_data(self):
        # 模拟延迟加载数据
        QTimer.singleShot(3000, self.show_data)  # 3秒后调用show_data方法

    def show_data(self):
        pass
    def load_data(self):
        # 模拟延迟加载数据
        QTimer.singleShot(3000, self.show_data)  # 3秒后调用show_data方法

    def show_data(self):
        pass


# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 图表
# @Time   : 2024-09-19 16:44
# @Author : 毛鹏
from .line import MangoLinePlot
from .pie import MangoPiePlot
__all__ = [
    'MangoLinePlot',
    'MangoPiePlot'
]


# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2025-05-25 23:31
# @Author : 毛鹏
from PySide6.QtCore import QThread, Signal
from PySide6.QtWidgets import QWidget

from mangoui.widgets.layout import MangoVBoxLayout


class DataLoadWorker(QThread):
    finished = Signal()

    def __init__(self, parent=None):
        super().__init__(parent)
        self.parent = parent

    def run(self):
        try:
            self.parent.load_page_data()  # type: ignore
        finally:
            self.finished.emit()


class MangoWidget(QWidget):

    def __init__(self, parent, *args, **kwargs):
        super().__init__(parent, *args, **kwargs)
        self.worker = None
        self.layout = MangoVBoxLayout()
        self.setLayout(self.layout)

    def show_data(self):
        if self.worker is not None and self.worker.isRunning():
            return
        self.worker = DataLoadWorker(self)
        self.worker.finished.connect(lambda: setattr(self, 'worker', None))
        self.worker.start()

    def load_page_data(self):
        pass



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 树形视图组件
# @Time   : 2025-11-25 10:25
# @Author : Qwen

from PySide6.QtCore import *
from PySide6.QtWidgets import *
from mangoui.settings.settings import THEME


class MangoTreeView(QTreeView):
    def __init__(self, parent=None, **kwargs):
        super().__init__(parent)
        self.kwargs = kwargs
        self.set_stylesheet()
        
    def set_stylesheet(self):
        style = f"""
        QTreeView {{
            background-color: {THEME.bg_100};
            border-radius: {THEME.border_radius};
            border: 1px solid {THEME.bg_300};
            color: {THEME.text_100};
            font-family: {THEME.font.family};
            font-size: {THEME.font.text_size}px;
            outline: none;
            padding: 2px;
        }}

        QTreeView::item {{
            padding: 4px;
            border-radius: {THEME.border_radius};
        }}

        QTreeView::item:selected {{
            background-color: {THEME.primary_100};
            color: white;
        }}

        QTreeView::item:hover {{
            background-color: {THEME.bg_200};
        }}

        QTreeView::item:selected:hover {{
            background-color: {THEME.primary_200};
        }}

        QTreeView:disabled {{
            background-color: {THEME.bg_200};
            color: {THEME.text_200};
        }}
        
        QTreeView::branch:has-siblings:!adjoins-item {{
            border-image: url(:/icons/vline.svg) 0;
        }}

        QTreeView::branch:has-siblings:adjoins-item {{
            border-image: url(:/icons/branch_more.svg) 0;
        }}

        QTreeView::branch:!has-children:!has-siblings:adjoins-item {{
            border-image: url(:/icons/branch_end.svg) 0;
        }}

        QTreeView::branch:has-children:!has-siblings:closed,
        QTreeView::branch:closed:has-children:has-siblings {{
            border-image: none;
            image: url(:/icons/arrow_right.svg);
        }}

        QTreeView::branch:open:has-children:!has-siblings,
        QTreeView::branch:open:has-children:has-siblings {{
            border-image: none;
            image: url(:/icons/arrow_down.svg);
        }}
        
        QTreeView QScrollBar:vertical {{
            border: none;
            background: {THEME.bg_300};
            width: 8px;
            margin: 0px 0px 0px 0px;
            border-radius: 0px;
        }}
        
        QTreeView QScrollBar::handle:vertical {{
            background: {THEME.bg_300};
            min-height: 25px;
            border-radius: 4px;
        }}
        """
        self.setStyleSheet(style)


class MangoTreeWidget(QTreeWidget):
    def __init__(self, parent=None, **kwargs):
        super().__init__(parent)
        self.kwargs = kwargs
        self.set_stylesheet()
        
    def set_stylesheet(self):
        style = f"""
        QTreeWidget {{
            background-color: {THEME.bg_100};
            border-radius: {THEME.border_radius};
            border: 1px solid {THEME.bg_300};
            color: {THEME.text_100};
            font-family: {THEME.font.family};
            font-size: {THEME.font.text_size}px;
            outline: none;
            padding: 2px;
        }}

        QTreeWidget::item {{
            padding: 4px;
            border-radius: {THEME.border_radius};
        }}

        QTreeWidget::item:selected {{
            background-color: {THEME.primary_100};
            color: white;
        }}

        QTreeWidget::item:hover {{
            background-color: {THEME.bg_200};
        }}

        QTreeWidget::item:selected:hover {{
            background-color: {THEME.primary_200};
        }}

        QTreeWidget:disabled {{
            background-color: {THEME.bg_200};
            color: {THEME.text_200};
        }}
        
        QTreeWidget::branch:has-siblings:!adjoins-item {{
            border-image: url(:/icons/vline.svg) 0;
        }}

        QTreeWidget::branch:has-siblings:adjoins-item {{
            border-image: url(:/icons/branch_more.svg) 0;
        }}

        QTreeWidget::branch:!has-children:!has-siblings:adjoins-item {{
            border-image: url(:/icons/branch_end.svg) 0;
        }}

        QTreeWidget::branch:has-children:!has-siblings:closed,
        QTreeWidget::branch:closed:has-children:has-siblings {{
            border-image: none;
            image: url(:/icons/arrow_right.svg);
        }}

        QTreeWidget::branch:open:has-children:!has-siblings,
        QTreeWidget::branch:open:has-children:has-siblings {{
            border-image: none;
            image: url(:/icons/arrow_down.svg);
        }}
        
        QTreeWidget QScrollBar:vertical {{
            border: none;
            background: {THEME.bg_300};
            width: 8px;
            margin: 0px 0px 0px 0px;
            border-radius: 0px;
        }}
        
        QTreeWidget QScrollBar::handle:vertical {{
            background: {THEME.bg_300};
            min-height: 25px;
            border-radius: 4px;
        }}
        """
        self.setStyleSheet(style)


# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2025-01-28 15:46
# @Author : 毛鹏

# qss_dict_11 = {
#     "theme_name": "浅紫色主题 v1.2",
#     # 主题色 - 保持与Theme类兼容
#     "primary_100": "#634c86",    # 主色（您指定的紫色）
#     "primary_200": "#c4b5fd",    # 主色（浅紫色）
#     "primary_300": "#f5f3ff",    # 主色（极浅紫色）
#     "accent_100": "#5f6a79",     # 强调色（您指定的灰蓝色）
#     "accent_200": "#8a7faf",     # 强调色（浅紫色）
#     "text_100": "#262626",       # 主要文本颜色
#     "text_200": "#525252",       # 次要文本颜色
#     "bg_100": "#ffffff",         # 背景色（纯白色）
#     "bg_200": "#f8f9fa",         # 次要背景色（极浅灰）
#     "bg_300": "#d6cfe2",         # 较深背景色（浅灰）
#     # 边距和边距颜色
#     "border": "1px solid #e9ecef",
#     "border_radius": "6px",      # 现代化圆角
#     # 字体
#     "font": {
#         "family": "'Inter', 'Segoe UI', '微软雅黑', sans-serif",  # 现代化字体
#         "title_size": 13,
#         "text_size": 11,
#         "weight": "normal"
#     },
#     # 其他颜色组，如通知、警告、成功、错误等
#     "group": {
#         "info": "#634c86",
#         "warning": "#f59e0b",
#         "success": "#22c55e",
#         "error": "#ef4444"
#     }
# }

qss_dict_1 = {
    "theme_name": "灰紫主题 v1.2",
    # 主色系 - 用于界面主要元素
    "primary_000": "#6A5A80",    # 深主色-深灰紫：用于取消按钮、次要操作
    "primary_100": "#8A7AA0",    # 主色-浅灰紫：用于确认按钮、重要标题
    "primary_200": "#D8D0EB",    # 次要主色-淡灰紫：用于悬停状态、次要元素
    "primary_300": "#F9F8FD",    # 背景主色-极淡灰紫：用于卡片背景、高亮区域

    # 强调色系 - 用于辅助元素和装饰
    "accent_100": "#7A7F89",     # 强调色-中性灰：用于图标、边框、分割线
    "accent_200": "#B0A8C5",     # 次要强调色-灰紫色：用于标签、徽章

    # 文本色系 - 确保良好的可读性
    "text_100": "#383738",       # 主要文本-深灰色：用于标题、重要文字
    "text_200": "#666666",       # 次要文本-中灰色：用于正文、描述文字

    # 背景色系 - 建立清晰的视觉层次
    "bg_100": "#FFFFFF",         # 主背景-纯白色：用于页面背景
    "bg_200": "#F8F7FC",         # 次要背景-极淡灰紫：用于卡片背景
    "bg_300": "#D5D0DE",         # 三级背景-中等灰紫：用于输入框、选中状态

    # 边框样式
    "border": "1px solid #f2f1f6",  # 边框样式-极淡灰紫边框
    "border_radius": "6px",      # 圆角大小-现代化圆角

    # 字体设置
    "font": {
        "family": "微软雅黑",  # 字体族-现代化无衬线字体
        "title_size": 13,        # 标题字号-13px
        "text_size": 11,         # 正文字号-11px
        "weight": "normal"       # 字重-常规
    },

    # 功能色系 - 用于系统状态反馈
    "group": {
        "info": "#8A7AA0",       # 信息色-与主色一致：用于信息提示
        "warning": "#E6A93C",    # 警告色-琥珀色：用于警告状态
        "success": "#38B27C",    # 成功色-绿色：用于成功状态
        "error": "#E87070"       # 错误色-红色：用于错误状态
    }
}


# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 2024-08-16 17:05
# @Author : 毛鹏

from PySide6.QtWidgets import *


class MangoDiv(QWidget):
    def __init__(self, color):
        super().__init__()

        self.layout = QHBoxLayout(self)
        self.layout.setContentsMargins(0, 5, 0, 5)
        self.frame_line = QFrame()
        self.frame_line.setStyleSheet(f"background: {color};")
        self.frame_line.setMaximumWidth(1)
        self.frame_line.setMinimumWidth(1)
        self.layout.addWidget(self.frame_line)
        self.setMaximumWidth(20)
        self.setMinimumWidth(20)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 布局
# @Time   : 2024-09-19 16:43
# @Author : 毛鹏
from .mango_layout import MangoGridLayout, MangoFormLayout, MangoHBoxLayout, MangoVBoxLayout

__all__ = [
    'MangoGridLayout',
    'MangoFormLayout',
    'MangoHBoxLayout',
    'MangoVBoxLayout'
]


# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 纯文本编辑器组件
# @Time   : 2025-11-25 10:15
# @Author : Qwen

from PySide6.QtCore import *
from PySide6.QtWidgets import *
from mangoui.settings.settings import THEME


class MangoPlainTextEdit(QPlainTextEdit):
    click = Signal(object)

    def __init__(self, placeholder="", value: str | None = None, subordinate: str | None = None, parent=None, **kwargs):
        super().__init__(parent)
        self.placeholder = placeholder
        self.value = value
        self.subordinate = subordinate
        self.kwargs = kwargs
        
        if placeholder:
            self.setPlaceholderText(placeholder)
            
        if self.value:
            self.set_value(self.value)
            
        self.set_stylesheet()
        
    def set_value(self, text: str):
        self.setPlainText(text)
        
    def get_value(self):
        return self.toPlainText()
        
    def set_stylesheet(self):
        style = f"""
        QPlainTextEdit {{
            background-color: {THEME.bg_100};
            border-radius: {THEME.border_radius};
            border: 1px solid {THEME.bg_300};
            padding: 8px 12px;
            selection-color: white;
            selection-background-color: {THEME.primary_100};
            color: {THEME.text_100};
            font-family: {THEME.font.family};
            font-size: {THEME.font.text_size}px;
            outline: none;
        }}

        QPlainTextEdit:focus {{
            border: 1px solid {THEME.primary_100};
            background-color: {THEME.bg_100};
        }}
        
        QPlainTextEdit:disabled {{
            background-color: {THEME.bg_200};
            color: {THEME.text_200};
        }}
        
        QPlainTextEdit QScrollBar:vertical {{
            border: none;
            background: {THEME.bg_300};
            width: 8px;
            margin: 0px 0px 0px 0px;
            border-radius: 0px;
        }}
        
        QPlainTextEdit QScrollBar::handle:vertical {{
            background: {THEME.bg_300};
            min-height: 25px;
            border-radius: 4px;
        }}
        """
        self.setStyleSheet(style)


from PySide6.QtCore import QPropertyAnimation
from PySide6.QtGui import *
from PySide6.QtWidgets import *

from mangoui.settings.settings import THEME


class MangoMessage(QWidget):
    def __init__(self, parent, message, style):
        super().__init__(parent)
        self.setWindowFlags(Qt.FramelessWindowHint | Qt.Tool | Qt.WindowStaysOnTopHint)  # type: ignore
        self.setFixedHeight(30)
        self.setAttribute(Qt.WA_TranslucentBackground)  # type: ignore

        self.layout = QHBoxLayout(self)
        self.layout.setContentsMargins(0, 0, 0, 0)

        self.label = QLabel(message)
        self.label.setAlignment(Qt.AlignCenter)  # type: ignore

        font_metrics = QFontMetrics(self.label.font())
        text_width = font_metrics.boundingRect(message).width()
        self.setFixedWidth(int(text_width * 1.5 if text_width < 110 else text_width * 1.3))

        self.layout.addStretch(1)
        self.layout.addWidget(self.label, 8)
        self.layout.addStretch(1)

        # 设置背景颜色和边框
        self.setStyleSheet(f"""
            QWidget {{
                background-color: {style};
                border-radius: {THEME.border_radius};
                border: 1px solid {THEME.bg_300};
                padding: 8px 16px;
            }}
            
            QLabel {{
                color: {THEME.text_100};
                font-family: {THEME.font.family};
                font-size: {THEME.font.text_size}px;
                font-weight: 500;
            }}
        """)

        # 设置渐隐效果
        self.animation = QPropertyAnimation(self, b"windowOpacity")
        self.animation.setDuration(1500)
        self.animation.setStartValue(1.0)
        self.animation.setEndValue(0.0)
        self.animation.finished.connect(self.close)
        self.animation.start()

        self.hovered = False

    def enterEvent(self, event):
        """鼠标进入事件，暂停渐隐动画"""
        if not self.hovered:
            self.hovered = True
            self.animation.stop()

    def leaveEvent(self, event):
        """鼠标离开事件，重新开始渐隐动画"""
        if self.hovered:
            self.hovered = False
            self.animation.start()



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 容器
# @Time   : 2024-09-19 16:42
# @Author : 毛鹏
from .mango_card import MangoCard
from .mango_group_box import MangoGroupBox
from .mango_stacked_widget import MangoStackedWidget
from .mango_tool_box import MangoToolBox

__all__ = [
    'MangoCard',
    'MangoGroupBox',
    'MangoStackedWidget',
    'MangoToolBox'
]


from PySide6.QtWidgets import QApplication, QPushButton, QLabel, QVBoxLayout, QWidget

# 定义两套主题
light_theme = {
    "primary_100": "#d4eaf7",
    "text_100": "#1d1c1c",
    "border": "1px solid #cccbc8",
    "border_radius": "7px",
    "font": {
        "title_size": 11,
    }
}

dark_theme = {
    "primary_100": "#2d2d2d",
    "text_100": "#ffffff",
    "border": "1px solid #3b3b3b",
    "border_radius": "7px",
    "font": {
        "title_size": 11,
    }
}


# 生成 QSS 样式
def generate_qss(theme):
    return f"""
        QPushButton {{
            background-color: {theme["primary_100"]};
            color: {theme["text_100"]};
            border: {theme["border"]};
            border-radius: {theme["border_radius"]};
        }}
        QLabel {{
            color: {theme["text_100"]};
            font-size: {theme["font"]["title_size"]}pt;
        }}
    """


# 切换主题
def apply_theme(theme):
    qss_style = generate_qss(theme)
    QApplication.instance().setStyleSheet(qss_style)


# 主窗口
class MainWindow(QWidget):
    def __init__(self):
        super().__init__()
        self.initUI()

    def initUI(self):
        layout = QVBoxLayout()

        button = QPushButton("切换主题")
        button.clicked.connect(self.toggle_theme)
        layout.addWidget(button)

        label = QLabel("这是一个标签")
        layout.addWidget(label)

        self.setLayout(layout)

    def toggle_theme(self):
        current_theme = dark_theme if QApplication.instance().styleSheet() == generate_qss(light_theme) else light_theme
        apply_theme(current_theme)


# 运行应用程序
if __name__ == "__main__":
    app = QApplication([])
    window = MainWindow()
    apply_theme(light_theme)  # 初始主题
    window.show()
    app.exec()



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-10-31 9:51
# @Author : 毛鹏
import asyncio
import os
import sys
from threading import Thread

# 添加项目根目录到Python路径
sys.path.insert(0, os.path.join(os.path.dirname(__file__), '..', '..'))

# 导入PySide6
from PySide6.QtWidgets import QApplication

# 直接从相对路径导入页面类
from home.home import HomePage
from input.input import InputPage
from display.display import DisplayPage
from container.container import ContainerPage
from layout.layout import LayoutPage
from layout.layout1 import Layout1Page
from layout.layout2 import Layout2Page
from menu.menu import MenuPage
from charts.charts import ChartsPage
from feedback.feedback import FeedbackPage
from window.window import WindowPage
from component.component_center import ComponentPage
from component.layout3 import Layout3Page
from component.layout4 import Layout4Page
from miscellaneous.miscellaneous import MiscellaneousPage

from mangoui.settings.settings import STYLE, MENUS
from mangoui.widgets.window.main_window.main_1.main_window import MangoMain1Window

os.environ["QT_FONT_DPI"] = "96"


class AsyncioThread(Thread):

    def __init__(self, loop):
        super().__init__()
        self._loop = loop
        self.daemon = True

    def run(self) -> None:
        self._loop.run_forever()


def t():
    loop = asyncio.new_event_loop()
    thd = AsyncioThread(loop)
    thd.start()
    return loop


def main():
    page_dict = {
        'home': HomePage,
        'input': InputPage,
        'display': DisplayPage,
        'container': ContainerPage,
        'layout': LayoutPage,
        'layout_page_1': Layout1Page,
        'layout_page_2': Layout2Page,
        'menu': MenuPage,
        'charts': ChartsPage,
        'feedback': FeedbackPage,
        'window': WindowPage,
        'component': ComponentPage,
        'component_page_3': Layout3Page,
        'component_page_4': Layout4Page,
        'miscellaneous': MiscellaneousPage,
    }

    app = QApplication([])
    login_window = MangoMain1Window(STYLE, MENUS, page_dict, t(), customize_titlebar=True)
    login_window.show()
    app.exec()


main()


# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-10-23 17:49
# @Author : 毛鹏
import matplotlib
matplotlib.use('Agg')
import matplotlib.pyplot as plt
from PySide6.QtGui import QPainterPath, QRegion
from PySide6.QtWidgets import QVBoxLayout, QWidget
from matplotlib.backends.backend_qt5agg import FigureCanvasQTAgg

from mangoui.settings.settings import THEME


class RoundedCanvas(FigureCanvasQTAgg):
    def __init__(self, fig, parent=None):
        super().__init__(fig)
        self.setParent(parent)
        self.radius = 8

    def paintEvent(self, event):
        # 创建圆角路径
        path = QPainterPath()
        rect = self.rect()
        path.addRoundedRect(rect, self.radius, self.radius)

        # 设置裁剪区域
        region = QRegion(path.toFillPolygon().toPolygon())
        self.setMask(region)

        # 调用父类绘制
        super().paintEvent(event)


matplotlib.rcParams['font.family'] = 'SimHei'
matplotlib.rcParams['axes.unicode_minus'] = False


class MangoPiePlot(QWidget):
    def __init__(self):
        super().__init__()
        # 设置卡片样式
        self.setStyleSheet(f"""
            background: {THEME.bg_100};
            border-radius: {THEME.border_radius};
            border: 1px solid {THEME.bg_300};
            padding: 16px;
        """)

        # 创建图表
        self.fig, self.ax = plt.subplots()
        self.fig.patch.set_facecolor('none')  # 透明背景
        self.canvas = RoundedCanvas(self.fig, self)
        
        # 设置图表标题样式
        self.ax.title.set_color(THEME.text_100)
        self.ax.title.set_fontsize(THEME.font.title_size)
        self.ax.title.set_fontfamily(THEME.font.family)

        # 布局设置
        layout = QVBoxLayout()
        layout.setContentsMargins(0, 0, 0, 0)
        layout.addWidget(self.canvas)
        self.setLayout(layout)

    def draw(self, data: list[dict]):
        self.ax.clear()  # 清除之前的图
        sizes = [item['value'] for item in data]
        labels = [item['name'] for item in data]
        # 使用更美观的颜色方案
        colors = ['#1f77b4', '#ff7f0e', '#2ca02c', '#d62728',
                  '#9467bd', '#8c564b', '#e377c2', '#7f7f7f',
                  '#bcbd22', '#17becf']
        if all(size == 0 for size in sizes):
            # 绘制默认饼状图
            default_sizes = [1, 1]  # 两个部分，表示无数据
            default_labels = ['无数据', '']
            # 无数据样式
            self.ax.pie(
                default_sizes,
                labels=default_labels,
                colors=['#CCCCCC', '#FFFFFF'],
                startangle=90,
                textprops={'color': THEME.text_200, 'fontsize': THEME.font.text_size}
            )
        else:
            # 绘制饼图
            # 绘制饼图
            self.ax.pie(
                sizes,
                labels=labels,
                colors=colors,
                autopct='%1.1f%%',
                startangle=90,
                textprops={'color': THEME.text_100, 'fontsize': THEME.font.text_size},
                wedgeprops={'linewidth': 1, 'edgecolor': 'white'}
            )
        self.ax.axis('equal')  # 确保饼状图是圆形
        self.canvas.draw()



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 线性进度条组件
# @Time   : 2025-11-25 11:25
# @Author : Qwen

from PySide6.QtCore import *
from PySide6.QtWidgets import *
from mangoui.settings.settings import THEME


class MangoProgressBar(QProgressBar):
    def __init__(self, parent=None, **kwargs):
        super().__init__(parent)
        self.kwargs = kwargs
        self.set_stylesheet()
        
    def set_stylesheet(self):
        style = f"""
        QProgressBar {{
            background-color: {THEME.bg_300};
            border-radius: {THEME.border_radius};
            border: 1px solid {THEME.bg_300};
            text-align: center;
            color: {THEME.text_100};
            font-family: {THEME.font.family};
            font-size: {THEME.font.text_size}px;
        }}

        QProgressBar::chunk {{
            background-color: {THEME.primary_100};
            border-radius: {THEME.border_radius};
        }}

        QProgressBar::chunk:hover {{
            background-color: {THEME.primary_200};
        }}

        QProgressBar:disabled {{
            background-color: {THEME.bg_200};
            color: {THEME.text_200};
        }}

        QProgressBar::chunk:disabled {{
            background-color: {THEME.text_200};
        }}
        """
        self.setStyleSheet(style)
        self.setMinimumHeight(20)


# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-08-30 14:51
# @Author : 毛鹏
from PySide6.QtGui import *
from PySide6.QtWidgets import *

from mangoui.settings.settings import THEME


class MangoDialog(QDialog):
    def __init__(self, tips: str, size: tuple = (400, 300)):
        super().__init__()
        self.setWindowTitle(tips)
        self.setFixedSize(*size)
        self.layout = QVBoxLayout()
        self.setLayout(self.layout)
        self.setWindowIcon(QIcon(':/icons/app_icon.png'))
        
        # 设置样式表
        self.setStyleSheet(f"""
            QDialog {{
                background-color: {THEME.bg_100};
                border-radius: {THEME.border_radius};
                border: 1px solid {THEME.bg_300};
            }}
            
            QDialog QLabel {{
                color: {THEME.text_100};
                font-family: {THEME.font.family};
                font-size: {THEME.font.text_size}px;
            }}
            
            QDialog QPushButton {{
                background-color: {THEME.primary_100};
                border: none;
                border-radius: {THEME.border_radius};
                color: white;
                padding: 8px 16px;
                font-family: {THEME.font.family};
                font-size: {THEME.font.text_size}px;
            }}
            
            QDialog QPushButton:hover {{
                background-color: {THEME.primary_200};
            }}
            
            QDialog QPushButton:pressed {{
                background-color: {THEME.primary_300};
            }}
        """)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-08-24 17:08
# @Author : 毛鹏

from PySide6.QtCore import *
from PySide6.QtGui import *
from PySide6.QtWidgets import *

from mangoui.settings.settings import THEME


class MangoLabel(QLabel):
    def __init__(self, text=None, parent=None, **kwargs):
        super().__init__(parent)
        self.parent = parent
        self.kwargs = kwargs
        self.set_style()
        self.setText(str(text) if text is not None else '')

        # 启用右键菜单
        self.setContextMenuPolicy(Qt.CustomContextMenu)
        self.customContextMenuRequested.connect(self.show_context_menu)

    def set_style(self, style=""):
        # 如果用户提供了自定义样式，则使用它
        if 'style' in self.kwargs and self.kwargs['style']:
            style = self.kwargs.get('style', style)
        else:
            # 否则使用默认样式
            style = f"""
            QLabel {{
                color: {THEME.text_100};
                background-color: transparent;
                font-family: {THEME.font.family};
                font-size: {THEME.font.text_size}px;
                font-weight: normal;  /* 去除加粗效果 */
                padding: 2px;
            }}
            """
        self.setStyleSheet(style)

    def show_context_menu(self, position):
        """显示右键上下文菜单"""
        context_menu = QMenu(self)
        # 删除了固定的菜单大小设置，让菜单根据内容自动调整大小
        context_menu.setStyleSheet(f"""
            QMenu {{
                background-color: {THEME.bg_100}; 
                border-radius: {THEME.border_radius};
                padding: 4px;
                border: 1px solid {THEME.bg_300};
                background-clip: border;
                min-width: 80px;  /* 设置最小宽度确保文字能完整显示 */
            }}
            QMenu::item {{
                padding: 6px 20px;
                margin: 2px;
                border-radius: 4px;
                background-color: transparent;
                color: {THEME.text_100};
            }}
            QMenu::item:selected {{
                background-color: {THEME.primary_200};
                color: {THEME.text_100};
            }}
        """)

        # 设置窗口标志，避免系统默认的菜单样式
        context_menu.setWindowFlags(context_menu.windowFlags() | Qt.FramelessWindowHint)
        context_menu.setAttribute(Qt.WA_TranslucentBackground)

        # 创建复制动作
        copy_action = QAction("复制", self)  # 删除了前面多余的空格
        copy_action.triggered.connect(self.copy_text)
        context_menu.addAction(copy_action)

        context_menu.exec_(self.mapToGlobal(position))
        
    def copy_text(self):
        """复制文本到剪贴板"""
        clipboard = QApplication.clipboard()
        clipboard.setText(self.text())
        from mangoui.components import success_message
        success_message(self.parent or self, '复制成功')




class MangoLabelWidget(QWidget):

    def __init__(self, text=None, parent=None, **kwargs):
        super().__init__(parent)
        self.kwargs = kwargs

        self.kwargs['style'] = f"""
            QLabel {{
                color: {THEME.text_100};
                background-color: {kwargs.get('background_color', THEME.primary_100)};
                padding: 6px 12px;
                border: 1px solid #e0e0e0;  /* 使用固定浅色边框 */
                border-radius: {THEME.border_radius};
                font-family: {THEME.font.family};
                font-size: {THEME.font.text_size}px;
                font-weight: normal;  /* 去除加粗效果 */
            }}
        """

        self.setMaximumHeight(25)
        self.mango_label = MangoLabel(text=text, parent=self, **self.kwargs)
        self.mango_label.setAlignment(Qt.AlignCenter)  # type: ignore

        layout = QHBoxLayout()
        layout.setAlignment(Qt.AlignCenter)  # type: ignore
        layout.addWidget(self.mango_label, alignment=Qt.AlignCenter)  # type: ignore
        layout.setContentsMargins(0, 0, 0, 0)
        self.setLayout(layout)


# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 2024-08-16 17:05
# @Author : 毛鹏

from PySide6.QtCore import *
from PySide6.QtGui import *
from PySide6.QtWidgets import *

from mangoui.settings.settings import THEME


class MangoPushButton(QPushButton):
    def __init__(
            self,
            text,
            parent=None,
            **kwargs
    ):
        super().__init__()
        self.setText(text)
        self.kwargs = kwargs

        if parent:
            self.setParent(parent)

        self.set_stylesheet()
        self.setCursor(Qt.PointingHandCursor)  # type: ignore

    def set_stylesheet(self, height=36, width=60):
        # 获取按钮颜色，如果没有指定则使用主题主色
        button_color = self.kwargs.get('color', THEME.primary_100)
        
        style = f'''
        QPushButton {{
            border: none;
            color: white;
            border-radius: {THEME.border_radius};
            background-color: {button_color};
            padding: 8px 16px;
            font-family: {THEME.font.family};
            font-size: {THEME.font.text_size}px;
            font-weight: 500;
            outline: none;
        }}
        QPushButton:hover {{
            background-color: {THEME.primary_200 if button_color == THEME.primary_100 else THEME.accent_200};
        }}
        QPushButton:pressed {{
            background-color: {THEME.primary_300 if button_color == THEME.primary_100 else THEME.bg_300};
        }}
        QPushButton:disabled {{
            background-color: {THEME.bg_200};
            color: {THEME.text_200};
        }}
        '''
        self.setStyleSheet(style)
        self.setMinimumHeight(height)
        self.setMinimumWidth(width)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 日期时间编辑器组件
# @Time   : 2025-11-25 10:05
# @Author : Qwen

from PySide6.QtCore import *
from PySide6.QtWidgets import *
from mangoui.settings.settings import THEME


class MangoDateEdit(QDateEdit):
    def __init__(self, parent=None, **kwargs):
        super().__init__(parent)
        self.kwargs = kwargs
        self.setCalendarPopup(True)
        self.set_stylesheet()
        
    def set_stylesheet(self):
        style = f"""
        QDateEdit {{
            background-color: {THEME.bg_100};
            border-radius: {THEME.border_radius};
            border: 1px solid {THEME.bg_300};
            padding: 8px 12px;
            selection-color: white;
            selection-background-color: {THEME.primary_100};
            color: {THEME.text_100};
            font-family: {THEME.font.family};
            font-size: {THEME.font.text_size}px;
            outline: none;
        }}

        QDateEdit:focus {{
            border: 1px solid {THEME.primary_100};
            background-color: {THEME.bg_100};
        }}
        
        QDateEdit:disabled {{
            background-color: {THEME.bg_200};
            color: {THEME.text_200};
        }}
        
        QDateEdit::drop-down {{
            subcontrol-origin: padding;
            subcontrol-position: top right;
            width: 20px;
            border-left-width: 1px;
            border-left-color: {THEME.bg_300};
            border-left-style: solid;
            border-top-right-radius: {THEME.border_radius};
            border-bottom-right-radius: {THEME.border_radius};
        }}

        QDateEdit::down-arrow {{
            image: url(:/icons/arrow_down.svg);
            width: 12px;
            height: 12px;
        }}
        
        QCalendarWidget QWidget {{
            alternate-background-color: {THEME.bg_200};
        }}

        QCalendarWidget QAbstractItemView:enabled {{
            font-size: {THEME.font.text_size}px;
            color: {THEME.text_100};
            background-color: {THEME.bg_100};
            selection-background-color: {THEME.primary_100};
            selection-color: white;
        }}

        QCalendarWidget QAbstractItemView:disabled {{
            color: {THEME.text_200};
        }}
        """
        self.setStyleSheet(style)
        self.setMinimumHeight(36)


class MangoDateTimeEdit(QDateTimeEdit):
    def __init__(self, parent=None, **kwargs):
        super().__init__(parent)
        self.kwargs = kwargs
        self.setCalendarPopup(True)
        self.set_stylesheet()
        
    def set_stylesheet(self):
        style = f"""
        QDateTimeEdit {{
            background-color: {THEME.bg_100};
            border-radius: {THEME.border_radius};
            border: 1px solid {THEME.bg_300};
            padding: 8px 12px;
            selection-color: white;
            selection-background-color: {THEME.primary_100};
            color: {THEME.text_100};
            font-family: {THEME.font.family};
            font-size: {THEME.font.text_size}px;
            outline: none;
        }}

        QDateTimeEdit:focus {{
            border: 1px solid {THEME.primary_100};
            background-color: {THEME.bg_100};
        }}
        
        QDateTimeEdit:disabled {{
            background-color: {THEME.bg_200};
            color: {THEME.text_200};
        }}
        
        QDateTimeEdit::drop-down {{
            subcontrol-origin: padding;
            subcontrol-position: top right;
            width: 20px;
            border-left-width: 1px;
            border-left-color: {THEME.bg_300};
            border-left-style: solid;
            border-top-right-radius: {THEME.border_radius};
            border-bottom-right-radius: {THEME.border_radius};
        }}

        QDateTimeEdit::down-arrow {{
            image: url(:/icons/arrow_down.svg);
            width: 12px;
            height: 12px;
        }}
        
        QCalendarWidget QWidget {{
            alternate-background-color: {THEME.bg_200};
        }}

        QCalendarWidget QAbstractItemView:enabled {{
            font-size: {THEME.font.text_size}px;
            color: {THEME.text_100};
            background-color: {THEME.bg_100};
            selection-background-color: {THEME.primary_100};
            selection-color: white;
        }}

        QCalendarWidget QAbstractItemView:disabled {{
            color: {THEME.text_200};
        }}
        """
        self.setStyleSheet(style)
        self.setMinimumHeight(36)


# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-11-02 21:24
# @Author : 毛鹏

from PySide6.QtCore import *
from PySide6.QtGui import *
from PySide6.QtWidgets import *

# 从具体的组件模块中导入所需的组件
from mangoui.widgets.container import MangoCard
from mangoui.widgets.display import MangoListWidget
from mangoui.widgets.layout import MangoVBoxLayout, MangoHBoxLayout, MangoGridLayout


class Layout3Page(QWidget):
    def __init__(self, parent):
        super().__init__()
        self.parent = parent
        self.layout = MangoVBoxLayout(self)
        
        # 创建滚动区域以容纳所有组件
        self.scroll_area = QScrollArea()
        self.scroll_area.setWidgetResizable(True)
        self.scroll_widget = QWidget()
        self.scroll_layout = MangoVBoxLayout(self.scroll_widget)
        
        # 标题
        title = QLabel("基础公共组件展示")
        title.setStyleSheet("font-size: 18px; font-weight: bold; margin: 10px 0;")
        self.scroll_layout.addWidget(title)

        # 使用网格布局组织基础公共组件，提高空间利用率
        self.components_grid = MangoGridLayout()
        self.components_grid.setColumnStretch(1, 1)
        
        # 卡片布局示例
        card_layout_widget = QWidget()
        card_layout = MangoHBoxLayout(card_layout_widget)
        
        for i in range(3):
            card_content_layout = MangoVBoxLayout()
            card_content_layout.addWidget(QLabel(f'卡片 {i+1} 内容'))
            card = MangoCard(card_content_layout, title=f'卡片 {i+1}')
            card_layout.addWidget(card)
        
        self.components_grid.addWidget(QLabel("卡片布局示例:"), 0, 0)
        self.components_grid.addWidget(card_layout_widget, 0, 1)

        # 列表布局示例
        list_widget = MangoListWidget()
        for i in range(10):
            list_widget.addItem(f"列表项 {i+1}")
        
        self.components_grid.addWidget(QLabel("列表布局示例:"), 1, 0)
        self.components_grid.addWidget(list_widget, 1, 1)
        
        self.scroll_layout.addLayout(self.components_grid)

        # 设置滚动区域
        self.scroll_area.setWidget(self.scroll_widget)
        self.layout.addWidget(self.scroll_area)


# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-11-02 21:24
# @Author : 毛鹏

from PySide6.QtCore import *
from PySide6.QtGui import *
from PySide6.QtWidgets import *

# 从具体的组件模块中导入所需的组件
from mangoui.widgets.display import (
    MangoProgressBar, MangoCircularProgress, MangoLabel, MangoMessage,
    MangoNotification, MangoPagination, MangoListView, MangoListWidget,
    MangoTreeView, MangoTreeWidget, MangoTableView, MangoTableWidget,
    MangoLCDNumber, MangoCalendarWidget, MangoStatusBar
)
from mangoui.components.table_list import TableList
from mangoui.models.models import TableColumnModel, TableMenuItemModel
from mangoui.settings.settings import THEME
from mangoui.widgets.input import MangoPushButton, MangoSlider
from mangoui.widgets.layout import MangoGridLayout, MangoVBoxLayout
from mangoui.widgets.window import MangoScrollArea


class DisplayPage(QWidget):
    table_menu = [
        {'name': '编辑', 'action': 'edit'},
        {'name': '删除', 'action': 'delete'}
    ]
    table_column = [
        {'key': 'id', 'name': 'ID', 'width': 7},
        {'key': 'name', 'name': '角色名称', 'width': 300},
        {'key': 'description', 'name': '角色描述', },
        {'key': 'label', 'name': '标签', 'type': 2},
        {'key': 'status', 'name': '状态', 'type': 3},
        {'key': 'ope', 'name': '操作', 'type': 1, 'width': 120},
    ]

    def __init__(self, parent):
        super().__init__()
        self.parent = parent
        self.page = 1
        self.page_size = 20
        self.layout = MangoVBoxLayout(self)
        
        # 创建滚动区域以容纳所有组件
        self.scroll_area = MangoScrollArea()
        self.scroll_widget = QWidget()
        self.scroll_layout = MangoVBoxLayout(self.scroll_widget)
        
        # 标题
        title = QLabel("显示组件展示")
        title.setStyleSheet("font-size: 18px; font-weight: bold; margin: 10px 0;")
        self.scroll_layout.addWidget(title)

        # 使用网格布局组织显示组件，提高空间利用率
        self.components_grid = MangoGridLayout()
        self.components_grid.setColumnStretch(1, 1)
        self.components_grid.setColumnStretch(3, 1)
        
        # 表格组件（原有）
        self.table_column = [TableColumnModel(**i) for i in self.table_column]
        self.table_menu = [TableMenuItemModel(**i) for i in self.table_menu]
        self.table_widget = TableList(self.table_column, self.table_menu, )
        self.table_widget.pagination.click.connect(self.pagination_clicked)
        self.table_widget.clicked.connect(self.callback)
        self.table_widget.table_widget.toggle_click.connect(self.update_data)
        but = MangoPushButton('点击')
        but.clicked.connect(self.batch)
        
        # 将表格组件添加到网格布局中，给它更大的空间
        self.components_grid.addWidget(QLabel("表格组件:"), 0, 0)
        self.components_grid.addWidget(but, 0, 1)
        self.components_grid.addWidget(self.table_widget, 1, 0, 1, 6)  # 占据4列的空间
        self.table_widget.setMinimumHeight(300)  # 设置最小高度

        # 进度条组件
        self.mango_progress_bar = MangoProgressBar()
        self.mango_progress_bar.setValue(75)
        self.components_grid.addWidget(QLabel("进度条:"), 2, 0)
        self.components_grid.addWidget(self.mango_progress_bar, 2, 1)
        
        self.mango_circular_progress = MangoCircularProgress(self)
        self.mango_circular_progress.set_value(80)
        self.components_grid.addWidget(QLabel("圆形进度条:"), 2, 2)
        self.components_grid.addWidget(self.mango_circular_progress, 2, 3)

        # 标签组件
        self.mango_label = MangoLabel("这是一个标签")
        self.components_grid.addWidget(QLabel("标签:"), 3, 0)
        self.components_grid.addWidget(self.mango_label, 3, 1)
        
        self.mango_message = MangoMessage(self, "这是一条消息", THEME.group.info)
        self.components_grid.addWidget(QLabel("消息:"), 3, 2)
        self.components_grid.addWidget(self.mango_message, 3, 3)

        # 通知和分页组件
        self.mango_notification = MangoNotification(self, "这是一条通知", THEME.group.success)
        self.components_grid.addWidget(QLabel("通知:"), 4, 0)
        self.components_grid.addWidget(self.mango_notification, 4, 1)
        
        self.mango_pagination = MangoPagination()
        self.components_grid.addWidget(QLabel("分页:"), 4, 2)
        self.components_grid.addWidget(self.mango_pagination, 4, 3)

        # 列表视图组件
        self.mango_list_view = MangoListView()
        list_model = QStringListModel()
        list_model.setStringList(["项目1", "项目2", "项目3", "项目4", "项目5"])
        self.mango_list_view.setModel(list_model)
        self.components_grid.addWidget(QLabel("列表视图:"), 5, 0)
        self.components_grid.addWidget(self.mango_list_view, 5, 1)
        
        self.mango_list_widget = MangoListWidget()
        for i in range(5):
            self.mango_list_widget.addItem(f"列表项 {i+1}")
        self.components_grid.addWidget(QLabel("列表控件:"), 5, 2)
        self.components_grid.addWidget(self.mango_list_widget, 5, 3)

        # 树形视图组件
        self.mango_tree_view = MangoTreeView()
        tree_model = QStandardItemModel()
        root = QStandardItem("根节点")
        for i in range(3):
            child = QStandardItem(f"子节点 {i+1}")
            for j in range(2):
                sub_child = QStandardItem(f"子节点 {i+1}-{j+1}")
                child.appendRow(sub_child)
            root.appendRow(child)
        tree_model.appendRow(root)
        self.mango_tree_view.setModel(tree_model)
        self.components_grid.addWidget(QLabel("树形视图:"), 6, 0)
        self.components_grid.addWidget(self.mango_tree_view, 6, 1)
        
        self.mango_tree_widget = MangoTreeWidget()
        tree_root = QTreeWidgetItem(self.mango_tree_widget, ["根节点"])
        for i in range(3):
            tree_child = QTreeWidgetItem(tree_root, [f"子节点 {i+1}"])
            for j in range(2):
                QTreeWidgetItem(tree_child, [f"子节点 {i+1}-{j+1}"])
        self.mango_tree_widget.expandAll()
        self.components_grid.addWidget(QLabel("树形控件:"), 6, 2)
        self.components_grid.addWidget(self.mango_tree_widget, 6, 3)

        # 表格视图组件
        self.mango_table_view = MangoTableView()
        table_model = QStandardItemModel(4, 3)
        table_model.setHorizontalHeaderLabels(["列1", "列2", "列3"])
        for i in range(4):
            for j in range(3):
                item = QStandardItem(f"数据 {i+1}-{j+1}")
                table_model.setItem(i, j, item)
        self.mango_table_view.setModel(table_model)
        self.components_grid.addWidget(QLabel("表格视图:"), 7, 0)
        self.components_grid.addWidget(self.mango_table_view, 7, 1)
        
        self.mango_table_widget = MangoTableWidget()
        self.mango_table_widget.setRowCount(4)
        self.mango_table_widget.setColumnCount(3)
        self.mango_table_widget.setHorizontalHeaderLabels(["列1", "列2", "列3"])
        for i in range(4):
            for j in range(3):
                self.mango_table_widget.setItem(i, j, QTableWidgetItem(f"数据 {i+1}-{j+1}"))
        self.components_grid.addWidget(QLabel("表格控件:"), 7, 2)
        self.components_grid.addWidget(self.mango_table_widget, 7, 3)

        # LCD数字显示和日历组件
        self.mango_lcd_number = MangoLCDNumber()
        self.mango_lcd_number.display(1234)
        self.components_grid.addWidget(QLabel("LCD数字显示:"), 8, 0)
        self.components_grid.addWidget(self.mango_lcd_number, 8, 1)
        
        self.mango_calendar_widget = MangoCalendarWidget()
        self.components_grid.addWidget(QLabel("日历控件:"), 8, 2)
        self.components_grid.addWidget(self.mango_calendar_widget, 8, 3)

        # 状态栏组件和滑块组件
        self.mango_status_bar = MangoStatusBar()
        self.mango_status_bar.showMessage("状态信息")
        self.components_grid.addWidget(QLabel("状态栏:"), 9, 0)
        self.components_grid.addWidget(self.mango_status_bar, 9, 1)
        
        self.mango_slider = MangoSlider()
        self.mango_slider.setOrientation(Qt.Horizontal)  # type: ignore
        self.mango_slider.setMinimum(0)
        self.mango_slider.setMaximum(100)
        self.mango_slider.setValue(50)
        self.components_grid.addWidget(QLabel("滑块:"), 9, 2)
        self.components_grid.addWidget(self.mango_slider, 9, 3)
        
        self.scroll_layout.addLayout(self.components_grid)

        # 设置滚动区域
        self.scroll_area.setWidget(self.scroll_widget)
        self.layout.addWidget(self.scroll_area)

    def show_data(self):
        data = []
        for i in range(50):
            data.append({
                "id": i,
                "create_time": "2023-07-13T12:39:57",
                "update_time": "2023-07-13T12:39:57",
                "name": "开发经理",
                "label": f"嘿嘿{i}",
                "status": 1,
                "description": "管理所有开发人员权限"
            })
        self.table_widget.set_data(data, 10)

    def update_data(self, data):
        print(data)

    def pagination_clicked(self, data):
        if data['action'] == 'prev':
            self.page = data['page']
        elif data['action'] == 'next':
            self.page = data['page']
        elif data['action'] == 'per_page':
            self.page_size = data['page']
        self.show_data()

    def callback(self, data):
        action = data.get('action')
        if action and hasattr(self, action):
            if data.get('row'):
                getattr(self, action)(row=data.get('row'))
            else:
                getattr(self, action)()

    def batch(self):
        print(self.table_widget.table_widget.get_selected_items())


# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-11-02 21:24
# @Author : 毛鹏

from PySide6.QtCore import *
from PySide6.QtGui import *
from PySide6.QtWidgets import *

# 从具体的组件模块中导入所需的组件
from mangoui.widgets.container import MangoCard
from mangoui.widgets.display import MangoLabel
from mangoui.widgets.layout import MangoVBoxLayout, MangoHBoxLayout, MangoGridLayout
from mangoui.widgets.window import MangoScrollArea


class HomePage(QWidget):
    def __init__(self, parent):
        super().__init__()
        self.parent = parent
        self.layout = MangoVBoxLayout(self)
        
        # 创建滚动区域以容纳所有组件
        self.scroll_area = MangoScrollArea()
        self.scroll_area.setWidgetResizable(True)
        self.scroll_widget = QWidget()
        self.scroll_layout = MangoVBoxLayout(self.scroll_widget)
        self.scroll_layout.setAlignment(Qt.AlignTop)  # type: ignore
        
        # 标题
        title = QLabel("芒果PySide6组件库")
        title.setStyleSheet("font-size: 24px; font-weight: bold; margin: 20px 0; color: #8a7aa0;")
        title.setAlignment(Qt.AlignCenter)  # type: ignore
        self.scroll_layout.addWidget(title)

        # 描述
        description = QLabel("欢迎使用芒果PySide6组件库！\n\n"
                           "这是一个基于PySide6的现代化UI组件库，提供了丰富的组件和布局方案。\n"
                           "通过左侧导航菜单可以查看各种组件的示例和用法。")
        description.setStyleSheet("font-size: 14px; margin: 20px; text-align: center;")
        description.setAlignment(Qt.AlignCenter)  # type: ignore
        description.setWordWrap(True)
        self.scroll_layout.addWidget(description)

        # 使用网格布局组织主页组件，提高空间利用率
        self.components_grid = MangoGridLayout()
        self.components_grid.setAlignment(Qt.AlignTop)  # type: ignore
        self.components_grid.setSpacing(20)
        
        # 组件统计
        stats_layout = MangoHBoxLayout()
        stats_layout.setSpacing(20)
        
        # 为每个卡片创建布局
        stats_layout1 = MangoVBoxLayout()
        stats_label1 = QLabel("15+ 组件")
        stats_label1.setStyleSheet("font-size: 16px; font-weight: bold; color: #8a7aa0;")
        stats_label1.setAlignment(Qt.AlignCenter)  # type: ignore
        stats_layout1.addWidget(stats_label1)
        stats_card1 = MangoCard(stats_layout1, title="输入组件")
        stats_card1.setFixedHeight(120)
        
        stats_layout2 = MangoVBoxLayout()
        stats_label2 = QLabel("12+ 组件")
        stats_label2.setStyleSheet("font-size: 16px; font-weight: bold; color: #8a7aa0;")
        stats_label2.setAlignment(Qt.AlignCenter)  # type: ignore
        stats_layout2.addWidget(stats_label2)
        stats_card2 = MangoCard(stats_layout2, title="显示组件")
        stats_card2.setFixedHeight(120)
        
        stats_layout3 = MangoVBoxLayout()
        stats_label3 = QLabel("5+ 组件")
        stats_label3.setStyleSheet("font-size: 16px; font-weight: bold; color: #8a7aa0;")
        stats_label3.setAlignment(Qt.AlignCenter)  # type: ignore
        stats_layout3.addWidget(stats_label3)
        stats_card3 = MangoCard(stats_layout3, title="容器组件")
        stats_card3.setFixedHeight(120)
        
        stats_layout4 = MangoVBoxLayout()
        stats_label4 = QLabel("3+ 组件")
        stats_label4.setStyleSheet("font-size: 16px; font-weight: bold; color: #8a7aa0;")
        stats_label4.setAlignment(Qt.AlignCenter)  # type: ignore
        stats_layout4.addWidget(stats_label4)
        stats_card4 = MangoCard(stats_layout4, title="菜单组件")
        stats_card4.setFixedHeight(120)
        
        stats_layout.addWidget(stats_card1)
        stats_layout.addWidget(stats_card2)
        stats_layout.addWidget(stats_card3)
        stats_layout.addWidget(stats_card4)
        
        stats_widget = QWidget()
        stats_widget.setLayout(stats_layout)
        self.components_grid.addWidget(stats_widget, 0, 0, 1, 2)

        # 特性介绍
        features_label = QLabel("特性介绍:")
        features_label.setStyleSheet("font-size: 18px; font-weight: bold; margin: 20px 0 10px 0; color: #383738;")
        
        features_widget = QWidget()
        features_layout = MangoVBoxLayout(features_widget)
        features_layout.setSpacing(10)
        features = [
            "现代化UI设计，支持主题定制",
            "丰富的组件库，涵盖常用UI元素",
            "响应式布局，适配不同屏幕尺寸",
            "易于扩展和自定义",
            "完善的文档和示例"
        ]
        
        for feature in features:
            feature_label = QLabel(f"• {feature}")
            feature_label.setStyleSheet("font-size: 14px; margin: 5px 20px; color: #383738;")
            feature_label.setWordWrap(True)
            features_layout.addWidget(feature_label)
        
        # 创建特性卡片
        features_card = MangoCard(features_layout)
        features_card.setFixedHeight(200)
        
        self.components_grid.addWidget(features_label, 1, 0)
        self.components_grid.addWidget(features_card, 2, 0, 1, 2)
        
        self.scroll_layout.addLayout(self.components_grid)

        # 添加一些间距
        self.scroll_layout.addStretch()

        # 设置滚动区域
        self.scroll_area.setWidget(self.scroll_widget)
        self.layout.addWidget(self.scroll_area)


# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-11-02 21:24
# @Author : 毛鹏

from PySide6.QtCore import *
from PySide6.QtGui import *
from PySide6.QtWidgets import *

# 从具体的组件模块中导入所需的组件
from mangoui.widgets.container import (
    MangoCard, MangoGroupBox, MangoStackedWidget, MangoToolBox
)
from mangoui.widgets.input import MangoPushButton
from mangoui.widgets.layout import MangoGridLayout, MangoVBoxLayout, MangoHBoxLayout


class ContainerPage(QWidget):
    def __init__(self, parent):
        super().__init__()
        self.parent = parent
        self.layout = MangoVBoxLayout(self)
        
        # 创建滚动区域以容纳所有组件
        self.scroll_area = QScrollArea()
        self.scroll_area.setWidgetResizable(True)
        self.scroll_widget = QWidget()
        self.scroll_layout = MangoVBoxLayout(self.scroll_widget)
        
        # 标题
        title = QLabel("容器组件展示")
        title.setStyleSheet("font-size: 18px; font-weight: bold; margin: 10px 0;")
        self.scroll_layout.addWidget(title)

        # 使用网格布局组织容器组件，提高空间利用率
        self.components_grid = MangoGridLayout()
        self.components_grid.setColumnStretch(1, 1)
        self.components_grid.setColumnStretch(3, 1)
        
        # 卡片容器（原有）
        card_layout = MangoVBoxLayout()
        card_layout.addWidget(QLabel('这是卡片内容'))
        self.mango_card = MangoCard(card_layout, title='卡片容器')
        self.components_grid.addWidget(QLabel("卡片容器:"), 0, 0)
        self.components_grid.addWidget(self.mango_card, 0, 1)

        # 分组框组件
        self.mango_group_box = MangoGroupBox("分组框")
        group_layout = MangoVBoxLayout()
        group_layout.addWidget(QLabel("分组框内容"))
        group_layout.addWidget(MangoPushButton("分组框按钮"))
        self.mango_group_box.setLayout(group_layout)
        self.components_grid.addWidget(QLabel("分组框:"), 0, 2)
        self.components_grid.addWidget(self.mango_group_box, 0, 3)

        # 堆叠窗口组件
        self.mango_stacked_widget = MangoStackedWidget()
        page1 = QLabel("堆叠页面1")
        page2 = QLabel("堆叠页面2")
        page3 = QLabel("堆叠页面3")
        self.mango_stacked_widget.addWidget(page1)
        self.mango_stacked_widget.addWidget(page2)
        self.mango_stacked_widget.addWidget(page3)
        self.components_grid.addWidget(QLabel("堆叠窗口:"), 1, 0)
        self.components_grid.addWidget(self.mango_stacked_widget, 1, 1)

        # 添加切换按钮
        switch_layout = MangoHBoxLayout()
        switch_btn1 = MangoPushButton("页面1")
        switch_btn2 = MangoPushButton("页面2")
        switch_btn3 = MangoPushButton("页面3")
        switch_btn1.clicked.connect(lambda: self.mango_stacked_widget.setCurrentIndex(0))
        switch_btn2.clicked.connect(lambda: self.mango_stacked_widget.setCurrentIndex(1))
        switch_btn3.clicked.connect(lambda: self.mango_stacked_widget.setCurrentIndex(2))
        switch_layout.addWidget(switch_btn1)
        switch_layout.addWidget(switch_btn2)
        switch_layout.addWidget(switch_btn3)
        
        switch_widget = QWidget()
        switch_widget.setLayout(switch_layout)
        self.components_grid.addWidget(switch_widget, 2, 0, 1, 2)

        # 工具箱组件
        self.mango_tool_box = MangoToolBox()
        toolbox_page1 = QLabel("工具箱页面1")
        toolbox_page2 = QLabel("工具箱页面2")
        toolbox_page3 = QLabel("工具箱页面3")
        self.mango_tool_box.addItem(toolbox_page1, "工具1")
        self.mango_tool_box.addItem(toolbox_page2, "工具2")
        self.mango_tool_box.addItem(toolbox_page3, "工具3")
        self.components_grid.addWidget(QLabel("工具箱:"), 1, 2)
        self.components_grid.addWidget(self.mango_tool_box, 1, 3, 2, 2)
        
        self.scroll_layout.addLayout(self.components_grid)

        # 设置滚动区域
        self.scroll_area.setWidget(self.scroll_widget)
        self.layout.addWidget(self.scroll_area)


# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-11-02 21:24
# @Author : 毛鹏

from PySide6.QtCore import *
from PySide6.QtGui import *
from PySide6.QtWidgets import *

# 从具体的组件模块中导入所需的组件
from mangoui.widgets.miscellaneous import (
    MangoCredits, MangoGrips
)
from mangoui.widgets.layout import MangoVBoxLayout, MangoGridLayout


class MiscellaneousPage(QWidget):
    def __init__(self, parent):
        super().__init__()
        self.parent = parent
        self.layout = MangoVBoxLayout(self)
        
        # 创建滚动区域以容纳所有组件
        self.scroll_area = QScrollArea()
        self.scroll_area.setWidgetResizable(True)
        self.scroll_widget = QWidget()
        self.scroll_layout = MangoVBoxLayout(self.scroll_widget)
        
        # 标题
        title = QLabel("其他组件展示")
        title.setStyleSheet("font-size: 18px; font-weight: bold; margin: 10px 0;")
        self.scroll_layout.addWidget(title)

        # 使用网格布局组织其他组件，提高空间利用率
        self.components_grid = MangoGridLayout()
        self.components_grid.setColumnStretch(1, 1)
        
        # 版权信息组件
        self.mango_credits = MangoCredits("Copyright © 2025 芒果测试平台", "1.0.0")
        self.components_grid.addWidget(QLabel("版权信息:"), 0, 0)
        self.components_grid.addWidget(self.mango_credits, 0, 1)

        # 调整大小组件
        self.mango_grips = MangoGrips(self, "bottom_right")
        self.components_grid.addWidget(QLabel("调整大小组件:"), 1, 0)
        self.components_grid.addWidget(self.mango_grips, 1, 1)
        
        self.scroll_layout.addLayout(self.components_grid)

        # 设置滚动区域
        self.scroll_area.setWidget(self.scroll_widget)
        self.layout.addWidget(self.scroll_area)


# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-11-02 21:24
# @Author : 毛鹏

from PySide6.QtCore import *
from PySide6.QtGui import *
from PySide6.QtWidgets import *

# 从具体的组件模块中导入所需的组件
from mangoui.widgets.input import MangoPushButton
from mangoui.components import (
    success_message, error_message, warning_message, info_message, error_notification,success_notification, warning_notification,info_notification
)
from mangoui.widgets.layout import MangoVBoxLayout, MangoGridLayout


class FeedbackPage(QWidget):
    def __init__(self, parent):
        super().__init__()
        self.parent = parent
        self.layout = MangoVBoxLayout(self)
        
        # 创建滚动区域以容纳所有组件
        self.scroll_area = QScrollArea()
        self.scroll_area.setWidgetResizable(True)
        self.scroll_widget = QWidget()
        self.scroll_layout = MangoVBoxLayout(self.scroll_widget)
        
        # 标题
        title = QLabel("反馈组件展示")
        title.setStyleSheet("font-size: 18px; font-weight: bold; margin: 10px 0;")
        self.scroll_layout.addWidget(title)

        # 使用网格布局组织反馈组件，提高空间利用率
        self.components_grid = MangoGridLayout()
        self.components_grid.setColumnStretch(1, 1)
        
        # 成功消息按钮
        success_btn = MangoPushButton('成功消息')
        success_btn.clicked.connect(self.success_message)
        self.components_grid.addWidget(QLabel("成功消息:"), 0, 0)
        self.components_grid.addWidget(success_btn, 0, 1)

        # 错误消息按钮
        error_btn = MangoPushButton('错误消息')
        error_btn.clicked.connect(self.error_message)
        self.components_grid.addWidget(QLabel("错误消息:"), 1, 0)
        self.components_grid.addWidget(error_btn, 1, 1)

        # 警告消息按钮
        warning_btn = MangoPushButton('警告消息')
        warning_btn.clicked.connect(self.warning_message)
        self.components_grid.addWidget(QLabel("警告消息:"), 2, 0)
        self.components_grid.addWidget(warning_btn, 2, 1)

        # 信息消息按钮
        info_btn = MangoPushButton('信息消息')
        info_btn.clicked.connect(self.info_message)
        self.components_grid.addWidget(QLabel("信息消息:"), 3, 0)
        self.components_grid.addWidget(info_btn, 3, 1)
        
        # 成功通知按钮
        success_notification_btn = MangoPushButton('成功通知')
        success_notification_btn.clicked.connect(self.success_notification)
        self.components_grid.addWidget(QLabel("成功通知:"), 4, 0)
        self.components_grid.addWidget(success_notification_btn, 4, 1)

        # 错误通知按钮
        error_notification_btn = MangoPushButton('错误通知')
        error_notification_btn.clicked.connect(self.error_notification)
        self.components_grid.addWidget(QLabel("错误通知:"), 5, 0)
        self.components_grid.addWidget(error_notification_btn, 5, 1)

        # 警告通知按钮
        warning_notification_btn = MangoPushButton('警告通知')
        warning_notification_btn.clicked.connect(self.warning_notification)
        self.components_grid.addWidget(QLabel("警告通知:"), 6, 0)
        self.components_grid.addWidget(warning_notification_btn, 6, 1)

        # 信息通知按钮
        info_notification_btn = MangoPushButton('信息通知')
        info_notification_btn.clicked.connect(self.info_notification)
        self.components_grid.addWidget(QLabel("信息通知:"), 7, 0)
        self.components_grid.addWidget(info_notification_btn, 7, 1)
        
        self.scroll_layout.addLayout(self.components_grid)

        # 设置滚动区域
        self.scroll_area.setWidget(self.scroll_widget)
        self.layout.addWidget(self.scroll_area)

    def success_message(self, _):
        success_message(self, '这是一个成功的提示')

    def error_message(self, _):
        error_message(self, '这是一个错误的提示')

    def warning_message(self, _):
        warning_message(self, '这是一个警告的提示')

    def info_message(self, _):
        info_message(self, '这是一个信息的提示')
        
    def success_notification(self, _):
        success_notification(self, '这是一个成功的通知')

    def error_notification(self, _):
        error_notification(self, '这是一个错误的通知')

    def warning_notification(self, _):
        warning_notification(self, '这是一个警告的通知')

    def info_notification(self, _):
        info_notification(self, '这是一个信息的通知')


# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-09-01 下午9:53
# @Author : 毛鹏

from PySide6.QtCore import *
from PySide6.QtGui import *
from PySide6.QtWidgets import *

from mangoui.settings.settings import THEME


class MangoNotification(QWidget):
    def __init__(self, parent, message, style):
        super().__init__(parent)
        self.style = style
        self.setWindowFlags(Qt.FramelessWindowHint | Qt.WindowStaysOnTopHint | Qt.Tool)  # type: ignore
        self.setFixedSize(240, 80)
        self.setObjectName("MangoNotification")
        self.setAttribute(Qt.WA_TranslucentBackground)  # type: ignore

        # 创建一个带圆角的 QFrame
        self.frame = QFrame(self)
        self.frame.setObjectName("notificationFrame")
        self.frame.setFixedSize(240, 80)
        self.frame.setFrameShape(QFrame.NoFrame)  # type: ignore
        self.frame.setStyleSheet(f"""
                   QFrame#notificationFrame {{
                       background-color: {self.style};
                       border-radius: 8px;
                   }}
               """)

        self.layout = QVBoxLayout(self.frame)
        self.layout.setContentsMargins(10, 0, 0, 0)
        self.layout.addWidget(QLabel(message))

        # 设置渐隐效果
        self.animation = QPropertyAnimation(self, b"windowOpacity")
        self.animation.setDuration(2000)
        self.animation.setStartValue(2.0)
        self.animation.setEndValue(0.0)
        self.animation.finished.connect(self.close)
        self.animation.start()
        self.hovered = False

    def enterEvent(self, event):
        """鼠标进入事件，暂停渐隐动画"""
        if not self.hovered:
            self.hovered = True
            self.animation.stop()  # 停止动画

    def leaveEvent(self, event):
        """鼠标离开事件，重新开始渐隐动画"""
        if self.hovered:
            self.hovered = False
            self.animation.start()  # 重新开始动画



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-10-30 15:35
# @Author : 毛鹏

from mangotools.mangos import Mango
from mangoui import *

from src.tools.components.message import response_message
from src.tools.methods import Methods


class Parent(QWidget):
    def show_data(self):
        pass

    def add(self, title='新建'):
        form_data = Mango.add_from_data(self)
        if hasattr(self, 'dialog_widget_size'):
            dialog = DialogWidget(title, form_data, self.dialog_widget_size)
        else:
            dialog = DialogWidget(title, form_data)
        dialog.clicked.connect(self.sub_options)  # type: ignore
        dialog.exec()
        if dialog.data:
            if hasattr(self, 'id_key'):
                dialog.data[self.id_key] = self.data['id']  # type: ignore
            response_model = Mango.post_save_data(self, dialog.data)
            if response_model:
                response_message(self, response_model)
            self.show_data()

    def edit(self, row, title='编辑'):
        form_data = Mango.edit_form_data(self, row, self.form_data, Methods)  # type: ignore
        if hasattr(self, 'dialog_widget_size'):
            dialog = DialogWidget(title, form_data, self.dialog_widget_size)
        else:
            dialog = DialogWidget(title, form_data)
        dialog.clicked.connect(self.sub_options)  # type: ignore
        dialog.exec()
        if dialog.data:
            response_model = Mango.put_save_data(self, row, dialog.data)
            if response_model:
                response_message(self, response_model)
            self.show_data()

    def delete(self, row):
        if hasattr(self, 'delete_callback'):
            response_model = self._delete(**self.delete_callback(row))  # type: ignore
        else:
            response_model = self._delete(row.get('id'))  # type: ignore
        response_message(self, response_model)
        self.show_data()



from mangoui.models.models import AppConfig, MenusModel, Theme
from mangoui.styles.qss import *

THEME = Theme(**qss_dict_1)

STYLE = AppConfig(**{
    "app_name": "芒果pyside6组件库",
    "version": "3.5.1",
    "copyright": "Copyright © By: 芒果味  2022-2025",
    "year": 2021,
    "theme_name": "mango",
    "custom_title_bar": True,
    "lef_menu_size": {
        "minimum": 50,
        "maximum": 240
    },
    "left_menu_content_margins": 3,
    "left_column_size": {
        "minimum": 0,
        "maximum": 240
    },
    "right_column_size": {
        "minimum": 0,
        "maximum": 240
    },
})

MENUS = MenusModel(**{
    "left_menus": [
        {
            "btn_icon": ":/icons/home.svg",
            "btn_id": "home",
            "btn_text": "首页",
            "btn_tooltip": "首页",
            "show_top": True,
            "is_active": True
        },
        {
            "btn_icon": ":/icons/app_icon.svg",
            "btn_id": "input",
            "btn_text": "输入组件",
            "btn_tooltip": "输入组件",
            "show_top": True,
            "is_active": False
        },
        {
            "btn_icon": ":/icons/calendar_clock.svg",
            "btn_id": "display",
            "btn_text": "显示组件",
            "btn_tooltip": "显示组件",
            "show_top": True,
            "is_active": False
        },
        {
            "btn_icon": ":/icons/command.svg",
            "btn_id": "container",
            "btn_text": "容器组件",
            "btn_tooltip": "容器组件",
            "show_top": True,
            "is_active": False
        },
        {
            "btn_icon": ":/icons/compass.svg",
            "btn_id": "layout",
            "btn_text": "布局组件",
            "btn_tooltip": "布局组件",
            "show_top": True,
            "is_active": False,
            "submenus": [
            {
                "btn_id": "layout_page_1",
                "btn_text": "基础布局展示",
                "btn_tooltip": "基础布局展示",
                "show_top": True,
                "is_active": False
            },
            {
                "btn_id": "layout_page_2",
                "btn_text": "高级布局展示",
                "btn_tooltip": "高级布局展示",
                "show_top": True,
                "is_active": False
            },]
        },
        {
            "btn_icon": ":/icons/down.svg",
            "btn_id": "menu",
            "btn_text": "菜单组件",
            "btn_tooltip": "菜单组件",
            "show_top": True,
            "is_active": False
        },
        {
            "btn_icon": ":/icons/fill.svg",
            "btn_id": "charts",
            "btn_text": "图表组件",
            "btn_tooltip": "图表组件",
            "show_top": True,
            "is_active": False
        },
        {
            "btn_icon": ":/icons/home.svg",
            "btn_id": "feedback",
            "btn_text": "反馈组件",
            "btn_tooltip": "反馈组件",
            "show_top": True,
            "is_active": False
        },
        {
            "btn_icon": ":/icons/icon_add_user.svg",
            "btn_id": "window",
            "btn_text": "窗口组件",
            "btn_tooltip": "窗口组件",
            "show_top": True,
            "is_active": False
        },
        {
            "btn_icon": ":/icons/icon_arrow_left.svg",
            "btn_id": "component",
            "btn_text": "公共组件",
            "btn_tooltip": "公共组件",
            "show_top": True,
            "is_active": False,
            "submenus": [
            {
                "btn_id": "component_page_3",
                "btn_text": "基础公共组件展示",
                "btn_tooltip": "基础公共组件展示",
                "show_top": True,
                "is_active": False
            },
            {
                "btn_id": "component_page_4",
                "btn_text": "高级公共组件展示",
                "btn_tooltip": "高级公共组件展示",
                "show_top": True,
                "is_active": False
            },]
        },
        {
            "btn_icon": ":/icons/icon_info.svg",
            "btn_id": "miscellaneous",
            "btn_text": "其他组件",
            "btn_tooltip": "其他组件",
            "show_top": True,
            "is_active": False
        }
    ],
    "title_bar_menus": [
        {
            "btn_icon": ":/icons/project.ico",
            "btn_id": "project",
            "btn_tooltip": "请选择项目",
            "is_active": False
        }, {
            "btn_icon": ":/icons/env.ico",
            "btn_id": "test_env",
            "btn_tooltip": "请选择测试环境",
            "is_active": False
        }
    ]
})



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-11-02 21:24
# @Author : 毛鹏

from PySide6.QtCore import *
from PySide6.QtGui import *
from PySide6.QtWidgets import *

# 从具体的组件模块中导入所需的组件
from mangoui.widgets.display import (
    MangoTreeWidget, MangoTableWidget
)
from mangoui.widgets.layout import MangoVBoxLayout, MangoGridLayout


class Layout4Page(QWidget):
    def __init__(self, parent):
        super().__init__()
        self.parent = parent
        self.layout = MangoVBoxLayout(self)
        
        # 创建滚动区域以容纳所有组件
        self.scroll_area = QScrollArea()
        self.scroll_area.setWidgetResizable(True)
        self.scroll_widget = QWidget()
        self.scroll_layout = MangoVBoxLayout(self.scroll_widget)
        
        # 标题
        title = QLabel("高级公共组件展示")
        title.setStyleSheet("font-size: 18px; font-weight: bold; margin: 10px 0;")
        self.scroll_layout.addWidget(title)

        # 使用网格布局组织高级公共组件，提高空间利用率
        self.components_grid = MangoGridLayout()
        self.components_grid.setColumnStretch(1, 1)
        
        # 树形布局示例
        tree_widget = MangoTreeWidget()
        root = QTreeWidgetItem(tree_widget, ["根节点"])
        for i in range(3):
            child = QTreeWidgetItem(root, [f"子节点 {i+1}"])
            for j in range(2):
                QTreeWidgetItem(child, [f"子节点 {i+1}-{j+1}"])
        tree_widget.expandAll()
        
        self.components_grid.addWidget(QLabel("树形布局示例:"), 0, 0)
        self.components_grid.addWidget(tree_widget, 0, 1)

        # 表格布局示例
        table_widget = MangoTableWidget()
        table_widget.setRowCount(5)
        table_widget.setColumnCount(3)
        table_widget.setHorizontalHeaderLabels(["列1", "列2", "列3"])
        for i in range(5):
            for j in range(3):
                table_widget.setItem(i, j, QTableWidgetItem(f"数据 {i+1}-{j+1}"))
        
        self.components_grid.addWidget(QLabel("表格布局示例:"), 1, 0)
        self.components_grid.addWidget(table_widget, 1, 1)
        
        self.scroll_layout.addLayout(self.components_grid)

        # 设置滚动区域
        self.scroll_area.setWidget(self.scroll_widget)
        self.layout.addWidget(self.scroll_area)


# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 字体下拉框组件
# @Time   : 2025-11-25 10:40
# @Author : Qwen

from PySide6.QtCore import *
from PySide6.QtWidgets import *
from mangoui.settings.settings import THEME


class MangoFontComboBox(QFontComboBox):
    def __init__(self, parent=None, **kwargs):
        super().__init__(parent)
        self.kwargs = kwargs
        self.set_stylesheet()
        
    def set_stylesheet(self):
        style = f"""
        QFontComboBox {{
            background-color: {THEME.bg_100};
            border-radius: {THEME.border_radius};
            border: 1px solid {THEME.bg_300};
            padding: 8px 12px;
            selection-color: white;
            selection-background-color: {THEME.primary_100};
            color: {THEME.text_100};
            font-family: {THEME.font.family};
            font-size: {THEME.font.text_size}px;
            outline: none;
        }}

        QFontComboBox:focus {{
            border: 1px solid {THEME.primary_100};
            background-color: {THEME.bg_100};
        }}
        
        QFontComboBox:disabled {{
            background-color: {THEME.bg_200};
            color: {THEME.text_200};
        }}
        
        QFontComboBox::drop-down {{
            subcontrol-origin: padding;
            subcontrol-position: top right;
            width: 20px;
            border-left-width: 1px;
            border-left-color: {THEME.bg_300};
            border-left-style: solid;
            border-top-right-radius: {THEME.border_radius};
            border-bottom-right-radius: {THEME.border_radius};
        }}

        QFontComboBox::down-arrow {{
            image: url(:/icons/arrow_down.svg);
            width: 12px;
            height: 12px;
        }}
        
        QFontComboBox QAbstractItemView {{
            background-color: {THEME.bg_100};
            border: 1px solid {THEME.bg_300};
            border-radius: {THEME.border_radius};
            selection-background-color: {THEME.primary_100};
            selection-color: white;
        }}
        """
        self.setStyleSheet(style)
        self.setMinimumHeight(36)


# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-09-19 11:29
# @Author : 毛鹏
from PySide6.QtCore import *
from PySide6.QtGui import *
from PySide6.QtWidgets import *

from mangoui.settings.settings import THEME


class MangoCard(QWidget):
    # 卡片组件
    clicked = Signal(str)

    def __init__(self, layout, title: str | None = None, parent=None, name='', **kwargs):
        super().__init__(parent)
        self.name = name  # 唯一标识
        self.kwargs = kwargs
        
        # 设置主布局
        self.main_layout = QVBoxLayout()
        self.main_layout.setContentsMargins(6, 6, 6, 6)  # 为阴影留出空间
        self.main_layout.setSpacing(0)
        
        # 创建卡片框架
        self.card_frame = QFrame()
        self.card_frame.setObjectName("cardFrame")
        
        # 设置卡片框架布局
        self.card_layout = QVBoxLayout(self.card_frame)
        self.card_layout.setContentsMargins(16, 16, 16, 16)  # 设置内边距
        self.card_layout.setSpacing(4)  # 移除布局间距效果
        
        # 如果有标题，添加标题
        if title:
            self.title_label = QLabel(title)
            self.title_label.setStyleSheet("background-color: transparent; border: none;")  # 确保标题背景透明
            font = QFont()
            font.setPointSize(14)  # 设置字体大小
            font.setBold(True)  # 设置为粗体
            self.title_label.setFont(font)
            self.card_layout.addWidget(self.title_label)
        
        # 添加内容布局
        if layout:
            layout.setContentsMargins(0, 0, 0, 0)
            self.card_layout.addLayout(layout)
        
        # 将卡片框架添加到主布局
        self.main_layout.addWidget(self.card_frame)
        self.setLayout(self.main_layout)
        
        # 设置样式
        self.set_stylesheet()

    def paintEvent(self, event):
        """重写paintEvent方法来绘制阴影效果"""
        # 先调用父类的paintEvent
        super().paintEvent(event)
        
        # 创建 QPainter 对象
        painter = QPainter(self)
        painter.setRenderHint(QPainter.Antialiasing)  # 抗锯齿
        
        # 获取卡片框架的几何信息
        rect = self.card_frame.geometry()
        
        # 创建阴影效果 - 绘制多层半透明矩形来模拟阴影
        for i in range(3):
            shadow_color = QColor(0, 0, 0, 15 - i * 5)  # 逐渐减小透明度
            painter.setPen(Qt.NoPen)
            painter.setBrush(shadow_color)
            shadow_rect = QRect(rect.x() + i, rect.y() + i, rect.width(), rect.height())
            painter.drawRoundedRect(shadow_rect, 8, 8)

    def enterEvent(self, event):
        if self.name:
            self.setCursor(Qt.PointingHandCursor)  # type: ignore
        super().enterEvent(event)
        
    def leaveEvent(self, event):
        if self.name:
            self.setCursor(Qt.ArrowCursor)  # type: ignore
        super().leaveEvent(event)

    def mousePressEvent(self, event):
        if event.button() == Qt.LeftButton:  # type: ignore
            self.clicked.emit(self.name)  # 发送点击信号
        super().mousePressEvent(event)  # 确保调用父类方法

    def get_background_color(self):
        """获取背景颜色"""
        background_color = self.kwargs.get('background_color')
        if background_color is None:
            background_color = '#F2F3F5'  # 使用浅灰色作为默认背景色
        return background_color

    def set_stylesheet(self):
        self.setObjectName('mangoCard')
        
        style = f"""
        QWidget#mangoCard {{
            background-color: transparent;
            border: none;
            padding: 0px;
        }}
        
        QFrame#cardFrame {{
            background-color: {self.get_background_color()};
            border: 1px solid {THEME.bg_300};
            border-radius: {THEME.border_radius};
        }}
        
        QWidget#mangoCard:hover QFrame#cardFrame {{
            border: 1px solid {THEME.primary_200};
        }}
        
        QLabel {{
            background-color: transparent;  /* 确保标签背景透明 */
            color: {THEME.text_100};
            font-family: {THEME.font.family};
            font-size: {THEME.font.text_size}px;
        }}
        """
        self.setStyleSheet(style)
        
    def setContentsMargins(self, left, top, right, bottom):
        """重写setContentsMargins方法，确保卡片框架也有正确的边距"""
        super().setContentsMargins(left, top, right, bottom)
        if hasattr(self, 'card_layout'):
            self.card_layout.setContentsMargins(16, 16, 16, 16)


# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 菜单
# @Time   : 2024-09-19 16:43
# @Author : 毛鹏

from .mango_menu import MangoMenu
from .mango_tabs import MangoTabs
from .mango_menu_bar import MangoMenuBar
from .mango_tool_bar import MangoToolBar

__all__ = [
    'MangoMenu',
    'MangoTabs',
    'MangoMenuBar',
    'MangoToolBar'
]


# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 其他
# @Time   : 2024-09-19 16:41
# @Author : 毛鹏
from .mango_credits import MangoCredits
from .mango_grips import MangoGrips

__all__ = [
    'MangoCredits',
    'MangoGrips'
]